@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -35,7 +35,7 @@ SELECT id
 ;';
   $result = pwg_query($query);
   $category_ids = array();
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     array_push($category_ids, $row['id']);
   }
@@ -76,7 +76,7 @@ SELECT id
 ;';
   $result = pwg_query($query);
   $element_ids = array();
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     array_push($element_ids, $row['id']);
   }
@@ -158,7 +158,7 @@ SELECT
     AND storage_category_id IS NULL
 ;';
     $result = pwg_query($query);
-    while ($row = mysql_fetch_assoc($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
       $file_path = $row['path'];
       $thumbnail_path = get_thumbnail_path($row);
@@ -247,7 +247,7 @@ SELECT
   {
     update_category($category_ids);
   }
-  
+
   trigger_action('delete_elements', $ids);
 }
 
@@ -421,210 +421,6 @@ function get_fs_directories($path, $recursive = true)
   return $dirs;
 }
 
-/**
- * inserts multiple lines in a table
- *
- * @param string table_name
- * @param array dbfields
- * @param array inserts
- * @return void
- */
-function mass_inserts($table_name, $dbfields, $datas)
-{
-  if (count($datas) != 0)
-  {
-    $first = true;
-
-    $query = 'SHOW VARIABLES LIKE \'max_allowed_packet\'';
-    list(, $packet_size) = mysql_fetch_row(pwg_query($query));
-    $packet_size = $packet_size - 2000; // The last list of values MUST not exceed 2000 character*/
-    $query = '';
-
-    foreach ($datas as $insert)
-    {
-      if (strlen($query) >= $packet_size)
-      {
-        pwg_query($query);
-        $first = true;
-      }
-
-      if ($first)
-      {
-        $query = '
-INSERT INTO '.$table_name.'
-  ('.implode(',', $dbfields).')
-  VALUES';
-        $first = false;
-      }
-      else
-      {
-        $query .= '
-  , ';
-      }
-
-      $query .= '(';
-      foreach ($dbfields as $field_id => $dbfield)
-      {
-        if ($field_id > 0)
-        {
-          $query .= ',';
-        }
-
-        if (!isset($insert[$dbfield]) or $insert[$dbfield] === '')
-        {
-          $query .= 'NULL';
-        }
-        else
-        {
-          $query .= "'".$insert[$dbfield]."'";
-        }
-      }
-      $query .= ')';
-    }
-    pwg_query($query);
-  }
-}
-
-define('MASS_UPDATES_SKIP_EMPTY', 1);
-/**
- * updates multiple lines in a table
- *
- * @param string table_name
- * @param array dbfields
- * @param array datas
- * @param int flags - if MASS_UPDATES_SKIP_EMPTY - empty values do not overwrite existing ones
- * @return void
- */
-function mass_updates($tablename, $dbfields, $datas, $flags=0)
-{
-  if (count($datas) == 0)
-    return;
-  // depending on the MySQL version, we use the multi table update or N update queries
-  if (count($datas) < 10 or version_compare(mysql_get_server_info(), '4.0.4') < 0)
-  { // MySQL is prior to version 4.0.4, multi table update feature is not available
-    foreach ($datas as $data)
-    {
-      $query = '
-UPDATE '.$tablename.'
-  SET ';
-      $is_first = true;
-      foreach ($dbfields['update'] as $key)
-      {
-        $separator = $is_first ? '' : ",\n    ";
-
-        if (isset($data[$key]) and $data[$key] != '')
-        {
-          $query.= $separator.$key.' = \''.$data[$key].'\'';
-        }
-        else
-        {
-          if ($flags & MASS_UPDATES_SKIP_EMPTY )
-            continue; // next field
-          $query.= "$separator$key = NULL";
-        }
-        $is_first = false;
-      }
-      if (!$is_first)
-      {// only if one field at least updated
-        $query.= '
-  WHERE ';
-        $is_first = true;
-        foreach ($dbfields['primary'] as $key)
-        {
-          if (!$is_first)
-          {
-            $query.= ' AND ';
-          }
-          if ( isset($data[$key]) )
-          {
-            $query.= $key.' = \''.$data[$key].'\'';
-          }
-          else
-          {
-            $query.= $key.' IS NULL';
-          }
-          $is_first = false;
-        }
-        pwg_query($query);
-      }
-    } // foreach update
-  } // if mysql_ver or count<X
-  else
-  {
-    // creation of the temporary table
-    $query = '
-SHOW FULL COLUMNS FROM '.$tablename;
-    $result = pwg_query($query);
-    $columns = array();
-    $all_fields = array_merge($dbfields['primary'], $dbfields['update']);
-    while ($row = mysql_fetch_array($result))
-    {
-      if (in_array($row['Field'], $all_fields))
-      {
-        $column = $row['Field'];
-        $column.= ' '.$row['Type'];
-
-        $nullable = true;
-        if (!isset($row['Null']) or $row['Null'] == '' or $row['Null']=='NO')
-        {
-          $column.= ' NOT NULL';
-          $nullable = false;
-        }
-        if (isset($row['Default']))
-        {
-          $column.= " default '".$row['Default']."'";
-        }
-        elseif ($nullable)
-        {
-          $column.= " default NULL";
-        }
-        if (isset($row['Collation']) and $row['Collation'] != 'NULL')
-        {
-          $column.= " collate '".$row['Collation']."'";
-        }
-        array_push($columns, $column);
-      }
-    }
-
-    $temporary_tablename = $tablename.'_'.micro_seconds();
-
-    $query = '
-CREATE TABLE '.$temporary_tablename.'
-(
-  '.implode(",\n  ", $columns).',
-  UNIQUE KEY the_key ('.implode(',', $dbfields['primary']).')
-)';
-
-    pwg_query($query);
-    mass_inserts($temporary_tablename, $all_fields, $datas);
-    if ( $flags & MASS_UPDATES_SKIP_EMPTY )
-      $func_set = create_function('$s', 'return "t1.$s = IFNULL(t2.$s, t1.$s)";');
-    else
-      $func_set = create_function('$s', 'return "t1.$s = t2.$s";');
-
-    // update of images table by joining with temporary table
-    $query = '
-UPDATE '.$tablename.' AS t1, '.$temporary_tablename.' AS t2
-  SET '.
-      implode(
-        "\n    , ",
-        array_map($func_set,$dbfields['update'])
-        ).'
-  WHERE '.
-      implode(
-        "\n    AND ",
-        array_map(
-          create_function('$s', 'return "t1.$s = t2.$s";'),
-          $dbfields['primary']
-          )
-        );
-    pwg_query($query);
-    $query = '
-DROP TABLE '.$temporary_tablename;
-    pwg_query($query);
-  }
-}
-
 /**
  * order categories (update categories.rank and global_rank database fields)
  * so that rank field are consecutive integers starting at 1 for each child
@@ -633,7 +429,7 @@ DROP TABLE '.$temporary_tablename;
 function update_global_rank()
 {
   $query = '
-SELECT id, if(id_uppercat is null,\'\',id_uppercat) AS id_uppercat, uppercats, rank, global_rank
+SELECT id, id_uppercat, uppercats, rank, global_rank
   FROM '.CATEGORIES_TABLE.'
   ORDER BY id_uppercat,rank,name';
 
@@ -643,7 +439,7 @@ SELECT id, if(id_uppercat is null,\'\',id_uppercat) AS id_uppercat, uppercats, r
   $current_uppercat = '';
 
   $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     if ($row['id_uppercat'] != $current_uppercat)
     {
@@ -789,7 +585,7 @@ SELECT uppercats
   WHERE id IN ('.implode(',', $cat_ids).')
 ;';
   $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $uppercats = array_merge($uppercats,
                              explode(',', $row['uppercats']));
@@ -813,10 +609,10 @@ function set_random_representant($categories)
 SELECT image_id
   FROM '.IMAGE_CATEGORY_TABLE.'
   WHERE category_id = '.$category_id.'
-  ORDER BY RAND()
-  LIMIT 0,1
+  ORDER BY '.DB_RANDOM_FUNCTION.'()
+  LIMIT 1
 ;';
-    list($representative) = mysql_fetch_array(pwg_query($query));
+    list($representative) = pwg_db_fetch_row(pwg_query($query));
 
     array_push(
       $datas,
@@ -876,7 +672,7 @@ SELECT id, uppercats, site_id
 '.wordwrap(implode(', ', $cat_ids), 80, "\n").')
 ;';
   $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     array_push($categories, $row);
   }
@@ -1124,7 +920,7 @@ SELECT DISTINCT(storage_category_id)
   {
     $query = '
 UPDATE '.IMAGES_TABLE.'
-  SET path = CONCAT(\''.$fulldirs[$cat_id].'\',\'/\',file)
+  SET path = '.pwg_db_concat(array("'".$fulldirs[$cat_id]."/'",'file')).'
   WHERE storage_category_id = '.$cat_id.'
 ;';
     pwg_query($query);
@@ -1152,7 +948,7 @@ SELECT element_id,
 
   $datas = array();
 
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     array_push(
       $datas,
@@ -1219,7 +1015,7 @@ SELECT id, id_uppercat, status, uppercats
   WHERE id IN ('.implode(',', $category_ids).')
 ;';
   $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $categories[$row['id']] =
       array(
@@ -1238,7 +1034,7 @@ SELECT uppercats
   FROM '.CATEGORIES_TABLE.'
   WHERE id = '.$new_parent.'
 ;';
-    list($new_parent_uppercats) = mysql_fetch_row(pwg_query($query));
+    list($new_parent_uppercats) = pwg_db_fetch_row(pwg_query($query));
 
     foreach ($categories as $category)
     {
@@ -1283,7 +1079,7 @@ SELECT status
   FROM '.CATEGORIES_TABLE.'
   WHERE id = '.$new_parent.'
 ;';
-    list($parent_status) = mysql_fetch_row(pwg_query($query));
+    list($parent_status) = pwg_db_fetch_row(pwg_query($query));
   }
 
   if ('private' == $parent_status)
@@ -1358,7 +1154,7 @@ function create_virtual_category($category_name, $parent_id=null)
   // is the given category name only containing blank spaces ?
   if (preg_match('/^\s*$/', $category_name))
   {
-    return array('error' => l10n('cat_error_name'));
+    return array('error' => l10n('The name of a category should not be empty'));
   }
 
   $parent_id = !empty($parent_id) ? $parent_id : 'NULL';
@@ -1368,7 +1164,7 @@ SELECT MAX(rank)
   FROM '.CATEGORIES_TABLE.'
   WHERE id_uppercat '.(is_numeric($parent_id) ? '= '.$parent_id : 'IS NULL').'
 ;';
-  list($current_rank) = mysql_fetch_array(pwg_query($query));
+  list($current_rank) = pwg_db_fetch_row(pwg_query($query));
 
   $insert = array(
     'name' => $category_name,
@@ -1384,21 +1180,21 @@ SELECT id, uppercats, global_rank, visible, status
   FROM '.CATEGORIES_TABLE.'
   WHERE id = '.$parent_id.'
 ;';
-    $parent = mysql_fetch_array(pwg_query($query));
+    $parent = pwg_db_fetch_assoc(pwg_query($query));
 
-    $insert{'id_uppercat'} = $parent{'id'};
-    $insert{'global_rank'} = $parent{'global_rank'}.'.'.$insert{'rank'};
+    $insert['id_uppercat'] = $parent['id'];
+    $insert['global_rank'] = $parent['global_rank'].'.'.$insert['rank'];
 
     // at creation, must a category be visible or not ? Warning : if the
     // parent category is invisible, the category is automatically create
     // invisible. (invisible = locked)
     if ('false' == $parent['visible'])
     {
-      $insert{'visible'} = 'false';
+      $insert['visible'] = 'false';
     }
     else
     {
-      $insert{'visible'} = boolean_to_string($conf['newcat_default_visible']);
+      $insert['visible'] = boolean_to_string($conf['newcat_default_visible']);
     }
 
     // at creation, must a category be public or private ? Warning : if the
@@ -1406,18 +1202,18 @@ SELECT id, uppercats, global_rank, visible, status
     // private.
     if ('private' == $parent['status'])
     {
-      $insert{'status'} = 'private';
+      $insert['status'] = 'private';
     }
     else
     {
-      $insert{'status'} = $conf['newcat_default_status'];
+      $insert['status'] = $conf['newcat_default_status'];
     }
   }
   else
   {
-    $insert{'visible'} = boolean_to_string($conf['newcat_default_visible']);
-    $insert{'status'} = $conf['newcat_default_status'];
-    $insert{'global_rank'} = $insert{'rank'};
+    $insert['visible'] = boolean_to_string($conf['newcat_default_visible']);
+    $insert['status'] = $conf['newcat_default_status'];
+    $insert['global_rank'] = $insert['rank'];
   }
 
   // we have then to add the virtual category
@@ -1430,7 +1226,7 @@ SELECT id, uppercats, global_rank, visible, status
     array($insert)
     );
 
-  $inserted_id = mysql_insert_id();
+  $inserted_id = pwg_db_insert_id(CATEGORIES_TABLE);
 
   $query = '
 UPDATE
@@ -1444,7 +1240,7 @@ UPDATE
   pwg_query($query);
 
   return array(
-    'info' => l10n('cat_virtual_added'),
+    'info' => l10n('Virtual category added'),
     'id'   => $inserted_id,
     );
 }
@@ -1496,7 +1292,7 @@ DELETE
  */
 function add_tags($tags, $images)
 {
-  if (count($tags) == 0 or count($tags) == 0)
+  if (count($tags) == 0 or count($images) == 0)
   {
     return;
   }
@@ -1563,7 +1359,7 @@ SELECT id
         )
       );
 
-    $page['tag_id_from_tag_name_cache'][$tag_name] = mysql_insert_id();
+    $page['tag_id_from_tag_name_cache'][$tag_name] = pwg_db_insert_id(TAGS_TABLE);
   }
   else
   {
@@ -1608,70 +1404,6 @@ DELETE
   }
 }
 
-/**
- * Do maintenance on all PWG tables
- *
- * @return none
- */
-function do_maintenance_all_tables()
-{
-  global $prefixeTable, $page;
-
-  $all_tables = array();
-
-  // List all tables
-  $query = 'SHOW TABLES LIKE \''.$prefixeTable.'%\'';
-  $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
-  {
-    array_push($all_tables, $row[0]);
-  }
-
-  // Repair all tables
-  $query = 'REPAIR TABLE '.implode(', ', $all_tables);
-  $mysql_rc = pwg_query($query);
-
-  // Re-Order all tables
-  foreach ($all_tables as $table_name)
-  {
-    $all_primary_key = array();
-
-    $query = 'DESC '.$table_name.';';
-    $result = pwg_query($query);
-    while ($row = mysql_fetch_array($result))
-    {
-      if ($row['Key'] == 'PRI')
-      {
-        array_push($all_primary_key, $row['Field']);
-      }
-    }
-
-    if (count($all_primary_key) != 0)
-    {
-      $query = 'ALTER TABLE '.$table_name.' ORDER BY '.implode(', ', $all_primary_key).';';
-      $mysql_rc = $mysql_rc && pwg_query($query);
-    }
-  }
-
-  // Optimize all tables
-  $query = 'OPTIMIZE TABLE '.implode(', ', $all_tables);
-  $mysql_rc = $mysql_rc && pwg_query($query);
-  if ($mysql_rc)
-  {
-    array_push(
-          $page['infos'],
-          l10n('Optimizations completed')
-          );
-  }
-  else
-  {
-    array_push(
-          $page['errors'],
-          l10n('Optimizations errors')
-          );
-  }
-}
-
 /**
  * Associate a list of images to a list of categories.
  *
@@ -1902,7 +1634,7 @@ SELECT id
         )
       );
 
-    $inserted_id = mysql_insert_id();
+    $inserted_id = pwg_db_insert_id(TAGS_TABLE);
 
     return array(
       'info' => sprintf(
@@ -2088,9 +1820,9 @@ SELECT name
   WHERE id = '.intval($group_id).'
 ;';
   $result = pwg_query($query);
-  if (mysql_num_rows($result) > 0)
+  if (pwg_db_num_rows($result) > 0)
   {
-    list($groupname) = mysql_fetch_row($result);
+    list($groupname) = pwg_db_fetch_row($result);
   }
   else
   {
@@ -2116,16 +1848,16 @@ SELECT '.$conf['user_fields']['username'].'
   WHERE '.$conf['user_fields']['id'].' = '.intval($user_id).'
 ;';
   $result = pwg_query($query);
-  if (mysql_num_rows($result) > 0)
+  if (pwg_db_num_rows($result) > 0)
   {
-    list($username) = mysql_fetch_row($result);
+    list($username) = pwg_db_fetch_row($result);
   }
   else
   {
     return false;
   }
 
-  return $username;
+  return stripslashes($username);
 }
 
 function get_newsletter_subscribe_base_url($language) {
@@ -2138,6 +1870,8 @@ function get_newsletter_subscribe_base_url($language) {
     'es_ES' => 'es.piwigo.org',
     'zh_CN' => 'cn.piwigo.org',
     'pl_PL' => 'pl.piwigo.org',
+    'hu_HU' => 'hu.piwigo.org',
+    'ru_RU' => 'ru.piwigo.org',
     );
 
   if (isset($domain_of[$language])) {
@@ -2146,4 +1880,128 @@ function get_newsletter_subscribe_base_url($language) {
 
   return 'http://'.$subscribe_domain.'/announcement/subscribe/';
 }
+
+/**
+ * Accordion menus need to know which section to open by default when
+ * loading the page
+ */
+function get_active_menu($menu_page)
+{
+  global $page;
+
+  if (isset($page['active_menu']))
+  {
+    return $page['active_menu'];
+  }
+
+  // specific cases
+  if ('element_set' == $menu_page)
+  {
+    if (isset($_GET['cat']) and is_numeric($_GET['cat']))
+    {
+      return 1;
+    }
+    else
+    {
+      return 0;
+    }
+  }
+
+  switch ($menu_page)
+  {
+    case 'photos_add':
+    case 'upload':
+    case 'rating':
+    case 'tags':
+    case 'picture_modify':
+      return 0;
+
+    case 'cat_list':
+    case 'cat_modify':
+    case 'cat_move':
+    case 'cat_options':
+    case 'cat_perm':
+    case 'permalinks':
+      return 1;
+
+    case 'user_list':
+    case 'user_perm':
+    case 'group_list':
+    case 'group_perm':
+    case 'notification_by_mail':
+      return 2;
+
+    case 'plugins_list':
+    case 'plugins_update':
+    case 'plugins_new':
+    case 'plugin':
+      return 3;
+
+    case 'site_manager':
+    case 'site_update':
+    case 'stats':
+    case 'history':
+    case 'maintenance':
+    case 'thumbnail':
+    case 'comments':
+      return 4;
+
+    case 'configuration':
+    case 'extend_for_templates':
+    case 'menubar':
+    case 'themes_new':
+    case 'themes_installed':
+    case 'theme':
+    case 'languages_installed':
+    case 'languages_new':
+      return 5;
+  }
+  return 0;
+}
+
+function get_fckb_taglist($query)
+{
+  $result = pwg_query($query);
+  $taglist = array();
+  while ($row = pwg_db_fetch_assoc($result))
+  {
+    array_push(
+      $taglist,
+      array(
+        'caption' => $row['tag_name'],
+        'value' => '~~'.$row['tag_id'].'~~',
+        )
+      );
+  }
+
+  return $taglist;
+}
+
+function get_fckb_tag_ids($raw_tags)
+{
+  // In $raw_tags we receive something like array('~~6~~', '~~59~~', 'New
+  // tag', 'Another new tag') The ~~34~~ means that it is an existing
+  // tag. I've added the surrounding ~~ to permit creation of tags like "10"
+  // or "1234" (numeric characters only)
+
+  $tag_ids = array();
+
+  foreach ($raw_tags as $raw_tag)
+  {
+    if (preg_match('/^~~(\d+)~~$/', $raw_tag, $matches))
+    {
+      array_push($tag_ids, $matches[1]);
+    }
+    else
+    {
+      // we have to create a new tag
+      array_push(
+        $tag_ids,
+        tag_id_from_tag_name($raw_tag)
+        );
+    }
+  }
+
+  return $tag_ids;
+}
 ?>
\ No newline at end of file
