@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -81,8 +81,8 @@ function do_timeout_treatment($post_keyname, $check_key_treated = array())
 
       $must_repost = true;
       array_push($page['errors'],
-        l10n_dec('nbm_background_treatment_redirect_second',
-                 'nbm_background_treatment_redirect_seconds',
+        l10n_dec('Execution time is out, treatment must be continue [Estimated time: %d second].',
+                 'Execution time is out, treatment must be continue [Estimated time: %d seconds].',
                   $time_refresh));
     }
   }
@@ -145,12 +145,12 @@ order by
 
   $result = pwg_query($query);
 
-  if (mysql_num_rows($result) > 0)
+  if (pwg_db_num_rows($result) > 0)
   {
     $inserts = array();
     $check_key_list = array();
 
-    while ($nbm_user = mysql_fetch_array($result))
+    while ($nbm_user = pwg_db_fetch_assoc($result))
     {
       // Calculate key
       $nbm_user['check_key'] = find_available_check_key();
@@ -174,8 +174,8 @@ order by
       (
         $page['infos'],
         sprintf(
-          l10n('nbm_user_x_added'),
-          $nbm_user['username'],
+          l10n('User %s [%s] added.'),
+          stripslashes($nbm_user['username']),
           get_email_address_as_display_text($nbm_user['mail_address'])
         )
       );
@@ -200,7 +200,7 @@ order by
         $query = 'delete from '.USER_MAIL_NOTIFICATION_TABLE.' where check_key in ('.implode(",", $quoted_check_key_list).');';
         $result = pwg_query($query);
 
-        redirect($base_url.get_query_string_diff(array(), false), l10n('nbm_redirect_msg'));
+        redirect($base_url.get_query_string_diff(array(), false), l10n('Processing treatment.')."\n".l10n('Please wait...'));
       }
     }
   }
@@ -238,7 +238,7 @@ function do_action_send_mail_notification($action = 'list_to_send', $check_key_l
 
   if (in_array($action, array('list_to_send', 'send')))
   {
-    list($dbnow) = mysql_fetch_row(pwg_query('SELECT NOW();'));
+    list($dbnow) = pwg_db_fetch_row(pwg_query('SELECT NOW();'));
 
     $is_action_send = ($action == 'send');
 
@@ -267,11 +267,11 @@ function do_action_send_mail_notification($action = 'list_to_send', $check_key_l
         // Prepare message after change language
         if ($is_action_send)
         {
-          $msg_break_timeout = l10n('nbm_break_timeout_send_mail');
+          $msg_break_timeout = l10n('Time to send mail is limited. Others mails are skipped.');
         }
         else
         {
-          $msg_break_timeout = l10n('nbm_break_timeout_list_user');
+          $msg_break_timeout = l10n('Prepared time for list of users to send mail is limited. Others users are not listed.');
         }
 
         // Begin nbm users environment
@@ -313,7 +313,7 @@ function do_action_send_mail_notification($action = 'list_to_send', $check_key_l
 
             if ($exist_data)
             {
-              $subject = '['.$conf['gallery_title'].']: '.l10n('nbm_object_news');
+              $subject = '['.$conf['gallery_title'].']: '.l10n('New elements added');
 
               // Assign current var for nbm mail
               assign_vars_nbm_mail_content($nbm_user);
@@ -381,14 +381,14 @@ function do_action_send_mail_notification($action = 'list_to_send', $check_key_l
                 array
                 (
                   'GOTO_GALLERY_TITLE' => $conf['gallery_title'],
-                  'GOTO_GALLERY_URL' => $conf['gallery_url'],
+                  'GOTO_GALLERY_URL' => get_gallery_home_url(),
                   'SEND_AS_NAME'      => $env_nbm['send_as_name'],
                 )
               );
 
               if (pwg_mail
                   (
-                    format_email($nbm_user['username'], $nbm_user['mail_address']),
+                    format_email(stripslashes($nbm_user['username']), $nbm_user['mail_address']),
                     array
                     (
                       'from' => $env_nbm['send_as_mail_formated'],
@@ -396,7 +396,6 @@ function do_action_send_mail_notification($action = 'list_to_send', $check_key_l
                       'email_format' => $env_nbm['email_format'],
                       'content' => $env_nbm['mail_template']->parse('notification_by_mail', true),
                       'content_format' => $env_nbm['email_format'],
-                      'template' => $nbm_user['template'],
                       'theme' => $nbm_user['theme']
                     )
                   ))
@@ -449,7 +448,7 @@ function do_action_send_mail_notification($action = 'list_to_send', $check_key_l
       {
         if ($is_action_send)
         {
-          array_push($page['errors'], l10n('nbm_no_user_to send_notifications_by_mail'));
+          array_push($page['errors'], l10n('No user to send notifications by mail.'));
         }
       }
     }
@@ -512,7 +511,7 @@ switch ($page['mode'])
       $updated_param_count = 0;
       // Update param
       $result = pwg_query('select param, value from '.CONFIG_TABLE.' where param like \'nbm\\_%\'');
-      while ($nbm_user = mysql_fetch_array($result))
+      while ($nbm_user = pwg_db_fetch_assoc($result))
       {
         if (isset($_POST[$nbm_user['param']]))
         {
@@ -531,7 +530,7 @@ where
       }
 
       array_push($page['infos'],
-        l10n_dec('nbm_updated_param_count', 'nbm_updated_params_count',
+        l10n_dec('%d parameter was updated.', '%d parameters were updated.',
           $updated_param_count));
 
       // Reload conf with new values
@@ -583,7 +582,7 @@ $template->assign
 (
   array
   (
-    'U_HELP' => add_url_params(get_root_url().'popuphelp.php', array('page' => 'notification_by_mail')),
+    'U_HELP' => get_root_url().'admin/popuphelp.php?page=notification_by_mail',
     'F_ACTION'=> $base_url.get_query_string_diff(array())
   )
 );
@@ -593,13 +592,13 @@ if (is_autorize_status(ACCESS_WEBMASTER))
   // TabSheet
   $tabsheet = new tabsheet();
   // TabSheet initialization
-  $tabsheet->add('param', l10n('nbm_param_mode'),
+  $tabsheet->add('param', l10n('Parameter'),
     add_url_params($base_url.get_query_string_diff(array('mode', 'select')),
         array('mode' => 'param')));
-  $tabsheet->add('subscribe', l10n('nbm_subscribe_mode'),
+  $tabsheet->add('subscribe', l10n('Subscribe'),
     add_url_params($base_url.get_query_string_diff(array('mode', 'select')),
       array('mode' => 'subscribe')));
-  $tabsheet->add('send', l10n('nbm_send_mode'),
+  $tabsheet->add('send', l10n('Send'),
     add_url_params($base_url.get_query_string_diff(array('mode', 'select')),
       array('mode' => 'send')));
   // TabSheet selection
@@ -650,8 +649,8 @@ switch ($page['mode'])
 
     $template->assign(
       array(
-        'L_CAT_OPTIONS_TRUE' => l10n('nbm_subscribe_col'),
-        'L_CAT_OPTIONS_FALSE' => l10n('nbm_unsubscribe_col')
+        'L_CAT_OPTIONS_TRUE' => l10n('Subscribed'),
+        'L_CAT_OPTIONS_FALSE' => l10n('Unsubscribed')
         )
       );
 
@@ -665,7 +664,7 @@ switch ($page['mode'])
     {
       if (get_boolean($nbm_user['enabled']))
       {
-        $opt_true[ $nbm_user['check_key'] ] = $nbm_user['username'].'['.get_email_address_as_display_text($nbm_user['mail_address']).']';
+        $opt_true[ $nbm_user['check_key'] ] = stripslashes($nbm_user['username']).'['.get_email_address_as_display_text($nbm_user['mail_address']).']';
         if ((isset($_POST['falsify']) and isset($_POST['cat_true']) and in_array($nbm_user['check_key'], $_POST['cat_true'])))
         {
           $opt_true_selected[] = $nbm_user['check_key'];
@@ -673,7 +672,7 @@ switch ($page['mode'])
       }
       else
       {
-        $opt_false[ $nbm_user['check_key'] ] = $nbm_user['username'].'['.get_email_address_as_display_text($nbm_user['mail_address']).']';
+        $opt_false[ $nbm_user['check_key'] ] = stripslashes($nbm_user['username']).'['.get_email_address_as_display_text($nbm_user['mail_address']).']';
         if (isset($_POST['trueify']) and isset($_POST['cat_false']) and in_array($nbm_user['check_key'], $_POST['cat_false']))
         {
           $opt_false_selected[] = $nbm_user['check_key'];
@@ -718,7 +717,7 @@ switch ($page['mode'])
                               isset($_POST['send_selection']) and // not init
                               !in_array($nbm_user['check_key'], $_POST['send_selection']) // not selected
                             )   ? '' : 'checked="checked"',
-              'USERNAME'=> $nbm_user['username'],
+              'USERNAME'=> stripslashes($nbm_user['username']),
               'EMAIL' => get_email_address_as_display_text($nbm_user['mail_address']),
               'LAST_SEND'=> $nbm_user['last_send']
               );
@@ -735,4 +734,4 @@ switch ($page['mode'])
 // +-----------------------------------------------------------------------+
 $template->assign_var_from_handle('ADMIN_CONTENT', 'notification_by_mail');
 
-?>
\ No newline at end of file
+?>
