@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -43,36 +43,36 @@ $query='
 SELECT galleries_url
   FROM '.SITES_TABLE.'
   WHERE id = '.$site_id;
-list($site_url) = mysql_fetch_row(pwg_query($query));
+list($site_url) = pwg_db_fetch_row(pwg_query($query));
 if (!isset($site_url))
 {
   die('site '.$site_id.' does not exist');
 }
 $site_is_remote = url_is_remote($site_url);
 
-list($dbnow) = mysql_fetch_row(pwg_query('SELECT NOW();'));
+list($dbnow) = pwg_db_fetch_row(pwg_query('SELECT NOW();'));
 define('CURRENT_DATE', $dbnow);
 
 $error_labels = array(
   'PWG-UPDATE-1' => array(
-    l10n('update_wrong_dirname_short'),
-    l10n('update_wrong_dirname_info')
+    l10n('wrong filename'),
+    l10n('The name of directories and files must be composed of letters, numbers, "-", "_" or "."')
     ),
   'PWG-UPDATE-2' => array(
-    l10n('update_missing_tn_short'),
-    l10n('update_missing_tn_info').implode(',', $conf['picture_ext'])
+    l10n('missing thumbnail'),
+    l10n('a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the category directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :').implode(',', $conf['picture_ext'])
     ),
   'PWG-ERROR-NO-FS' => array(
-    l10n('update_missing_file_or_dir'),
-    l10n('update_missing_file_or_dir_info')
+    l10n('File/directory read error'),
+    l10n('The file or directory cannot be accessed (either it does not exist or the access is denied)')
     ),
   'PWG-ERROR-VERSION' => array(
-    l10n('update_err_pwg_version_differs'),
-    l10n('update_err_pwg_version_differs_info')
+    l10n('Piwigo version differs on the remote site'),
+    l10n('Version of create_listing_file.php on the remote site and Piwigo must be the same')
     ),
   'PWG-ERROR-NOLISTING' => array(
-    l10n('update_err_remote_listing_not_found'),
-    l10n('update_err_remote_listing_not_found_info')
+    l10n('listing.xml file was not found'),
+    l10n('listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager')
     )
   );
 $errors = array();
@@ -148,7 +148,7 @@ SELECT id, uppercats, global_rank, status, visible
     if (isset($_POST['subcats-included']) and $_POST['subcats-included'] == 1)
     {
       $query.= '
-    AND uppercats REGEXP \'(^|,)'.$_POST['cat'].'(,|$)\'
+    AND uppercats '.DB_REGEX_OPERATOR.' \'(^|,)'.$_POST['cat'].'(,|$)\'
 ';
     }
     else
@@ -185,7 +185,7 @@ SELECT id, uppercats, global_rank, status, visible
 SELECT id
   FROM '.CATEGORIES_TABLE;
   $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $next_rank[$row['id']] = 1;
   }
@@ -196,7 +196,7 @@ SELECT id_uppercat, MAX(rank)+1 AS next_rank
   FROM '.CATEGORIES_TABLE.'
   GROUP BY id_uppercat';
   $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     // for the id_uppercat NULL, we write 'NULL' and not the empty string
     if (!isset($row['id_uppercat']) or $row['id_uppercat'] == '')
@@ -207,10 +207,7 @@ SELECT id_uppercat, MAX(rank)+1 AS next_rank
   }
 
   // next category id available
-  $query = '
-SELECT IF(MAX(id)+1 IS NULL, 1, MAX(id)+1) AS next_id
-  FROM '.CATEGORIES_TABLE;
-  list($next_id) = mysql_fetch_array(pwg_query($query));
+  $next_id = pwg_db_nextval('id', CATEGORIES_TABLE);
 
   // retrieve sub-directories fulldirs from the site reader
   $fs_fulldirs = $site_reader->get_full_directories($basedir);
@@ -246,34 +243,34 @@ SELECT IF(MAX(id)+1 IS NULL, 1, MAX(id)+1) AS next_id
         'uploadable'  => $site_is_remote
           ? 'false'
           : boolean_to_string($conf['newcat_default_uploadable']),
-        'status'      => $conf{'newcat_default_status'},
-        'visible'     => boolean_to_string($conf{'newcat_default_visible'}),
+        'status'      => $conf['newcat_default_status'],
+        'visible'     => boolean_to_string($conf['newcat_default_visible']),
         );
 
       if (isset($db_fulldirs[dirname($fulldir)]))
       {
         $parent = $db_fulldirs[dirname($fulldir)];
 
-        $insert{'id_uppercat'} = $parent;
-        $insert{'uppercats'} =
-          $db_categories[$parent]['uppercats'].','.$insert{'id'};
-        $insert{'rank'} = $next_rank[$parent]++;
-        $insert{'global_rank'} =
-          $db_categories[$parent]['global_rank'].'.'.$insert{'rank'};
+        $insert['id_uppercat'] = $parent;
+        $insert['uppercats'] =
+          $db_categories[$parent]['uppercats'].','.$insert['id'];
+        $insert['rank'] = $next_rank[$parent]++;
+        $insert['global_rank'] =
+          $db_categories[$parent]['global_rank'].'.'.$insert['rank'];
         if ('private' == $db_categories[$parent]['status'])
         {
-          $insert{'status'} = 'private';
+          $insert['status'] = 'private';
         }
         if ('false' == $db_categories[$parent]['visible'])
         {
-          $insert{'visible'} = 'false';
+          $insert['visible'] = 'false';
         }
       }
       else
       {
-        $insert{'uppercats'} = $insert{'id'};
+        $insert['uppercats'] = $insert['id'];
         $insert{'rank'} = $next_rank['NULL']++;
-        $insert{'global_rank'} = $insert{'rank'};
+        $insert['global_rank'] = $insert['rank'];
       }
 
       array_push($inserts, $insert);
@@ -281,20 +278,20 @@ SELECT IF(MAX(id)+1 IS NULL, 1, MAX(id)+1) AS next_id
         $infos,
         array(
           'path' => $fulldir,
-          'info' => l10n('update_research_added')
+          'info' => l10n('added')
           )
         );
 
       // add the new category to $db_categories and $db_fulldirs array
       $db_categories[$insert{'id'}] =
         array(
-          'id' => $insert{'id'},
-          'status' => $insert{'status'},
-          'visible' => $insert{'visible'},
-          'uppercats' => $insert{'uppercats'},
-          'global_rank' => $insert{'global_rank'}
+          'id' => $insert['id'],
+          'status' => $insert['status'],
+          'visible' => $insert['visible'],
+          'uppercats' => $insert['uppercats'],
+          'global_rank' => $insert['global_rank']
           );
-      $db_fulldirs[$fulldir] = $insert{'id'};
+      $db_fulldirs[$fulldir] = $insert['id'];
       $next_rank[$insert{'id'}] = 1;
     }
     else
@@ -330,7 +327,7 @@ SELECT IF(MAX(id)+1 IS NULL, 1, MAX(id)+1) AS next_id
     array_push($to_delete, $db_fulldirs[$fulldir]);
     unset($db_fulldirs[$fulldir]);
     array_push($infos, array('path' => $fulldir,
-                             'info' => l10n('update_research_deleted')));
+                             'info' => l10n('deleted')));
   }
   if (count($to_delete) > 0)
   {
@@ -386,7 +383,7 @@ SELECT file,storage_category_id
 '.wordwrap(implode(', ', $cat_ids), 80, "\n").')
     AND validated = \'false\'';
     $result = pwg_query($query);
-    while ($row = mysql_fetch_array($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
       array_push(
         $db_unvalidated,
@@ -399,10 +396,7 @@ SELECT file,storage_category_id
   }
 
   // next element id available
-  $query = '
-SELECT IF(MAX(id)+1 IS NULL, 1, MAX(id)+1) AS next_element_id
-  FROM '.IMAGES_TABLE;
-  list($next_element_id) = mysql_fetch_array(pwg_query($query));
+  $next_element_id = pwg_db_nextval('id', IMAGES_TABLE);
 
   $start = get_moment();
 
@@ -470,7 +464,7 @@ SELECT IF(MAX(id)+1 IS NULL, 1, MAX(id)+1) AS next_element_id
       array_push(
         $insert_links,
         array(
-          'image_id'    => $insert{'id'},
+          'image_id'    => $insert['id'],
           'category_id' => $insert['storage_category_id'],
           )
         );
@@ -478,8 +472,8 @@ SELECT IF(MAX(id)+1 IS NULL, 1, MAX(id)+1) AS next_element_id
       array_push(
         $infos,
         array(
-          'path' => $insert{'path'},
-          'info' => l10n('update_research_added')
+          'path' => $insert['path'],
+          'info' => l10n('added')
           )
         );
 
@@ -520,7 +514,7 @@ SELECT IF(MAX(id)+1 IS NULL, 1, MAX(id)+1) AS next_element_id
   {
     array_push($to_delete_elements, array_search($path, $db_elements));
     array_push($infos, array('path' => $path,
-                             'info' => l10n('update_research_deleted')));
+                             'info' => l10n('deleted')));
   }
   if (count($to_delete_elements) > 0)
   {
@@ -555,7 +549,7 @@ SELECT id,file,storage_category_id,infos
 
     $waiting_to_delete = array();
 
-    while ($row = mysql_fetch_array($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
       $data = array();
 
@@ -564,7 +558,7 @@ SELECT id
   FROM '.IMAGES_TABLE.'
   WHERE storage_category_id = '.$row['storage_category_id'].'
     AND file = \''.$row['file'].'\'';
-      list($data['id']) = mysql_fetch_array(pwg_query($query));
+      list($data['id']) = pwg_db_fetch_row(pwg_query($query));
 
       foreach ($fields['update'] as $field)
       {
@@ -834,7 +828,7 @@ $template->set_filenames(array('update'=>'site_update.tpl'));
 $result_title = '';
 if (isset($simulate) and $simulate)
 {
-  $result_title.= l10n('update_simulation_title').' ';
+  $result_title.= l10n('[Simulation]').' ';
 }
 
 // used_metadata string is displayed to inform admin which metadata will be
@@ -849,10 +843,10 @@ $template->assign(
   array(
     'SITE_URL'=>$site_url,
     'U_SITE_MANAGER'=> get_root_url().'admin.php?page=site_manager',
-    'L_RESULT_UPDATE'=>$result_title.l10n('update_part_research'),
-    'L_RESULT_METADATA'=>$result_title.l10n('update_result_metadata'),
+    'L_RESULT_UPDATE'=>$result_title.l10n('Search for new images in the directories'),
+    'L_RESULT_METADATA'=>$result_title.l10n('Metadata synchronization results'),
     'METADATA_LIST' => $used_metadata,
-    'U_HELP' => get_root_url().'popuphelp.php?page=synchronize',
+    'U_HELP' => get_root_url().'admin/popuphelp.php?page=synchronize',
     ));
 
 // +-----------------------------------------------------------------------+
@@ -896,11 +890,7 @@ else
   $cat_selected = array();
 }
 
-$tpl_introduction['privacy_level_options']=array();
-foreach ($conf['available_permission_levels'] as $level)
-{
-  $tpl_introduction['privacy_level_options'][$level] = l10n( sprintf('Level %d', $level) );
-}
+$tpl_introduction['privacy_level_options'] = get_privacy_level_options();
 
 $template->assign('introduction', $tpl_introduction);
 
