@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -30,7 +30,7 @@
  *
  * It is recommended to let config_default.inc.php as provided and to
  * overwrite configuration in your local configuration file
- * config_local.inc.php. See tools/config_local.inc.php as an example.
+ * local/config/config.inc.php. See tools/config.inc.php as an example.
  *
  * Why having some parameters in config table and others in
  * config_*.inc.php? Modifying config_*.inc.php is a "hard" task for low
@@ -264,6 +264,9 @@ $conf['allow_html_descriptions'] = true;
 // contain characters among : a to z (case insensitive), "-" or "_".
 $conf['prefix_thumbnail'] = 'TN-';
 
+// dir_thumbnail : directory where thumbnail reside.
+$conf['dir_thumbnail'] = 'thumbnail';
+
 // users_page: how many users to display in screen
 // Administration>Identification>Users?
 $conf['users_page'] = 20;
@@ -322,16 +325,16 @@ $conf['default_redirect_method'] = 'http';
 // Define using double password type in admin's users management panel
 $conf['double_password_type_in_admin'] = false;
 
+// Define if logins must be case sentitive or not at users registration. ie :
+// If set true, the login "user" will equal "User" or "USER" or "user",
+// etc. ... And it will be impossible to use such login variation to create a
+// new user account.
+$conf['insensitive_case_logon'] = false;
+
 // how should we check for unicity when adding a photo. Can be 'md5sum' or
 // 'filename'
 $conf['uniqueness_mode'] = 'md5sum';
 
-// home_page : relative url of the homepage. Empty by default.
-// It points to the index of the gallery.
-// This parameter is used if home page is not index.php of the gallery.
-// We suggest avoid the names "index.htm" or "index.html" if you set $conf['php_extension_in_urls'] to false.
-$conf['home_page'] = '';
-
 // +-----------------------------------------------------------------------+
 // |                               metadata                                |
 // +-----------------------------------------------------------------------+
@@ -455,6 +458,9 @@ $conf['debug_l10n'] = false;
 // activate template debugging - a new window will appear
 $conf['debug_template'] = false;
 
+// save copies of sent mails into local data dir
+$conf['debug_mail'] = false;
+
 // die_on_sql_error: if an SQL query fails, should everything stop?
 $conf['die_on_sql_error'] = false;
 
@@ -469,6 +475,11 @@ $conf['compiled_template_cache_language'] = false;
 // better performance.
 $conf['template_compile_check'] = true;
 
+// This forces Smarty to (re)compile templates on every invocation. This is
+// handy for development and debugging. It should never be used in a
+// production environment.
+$conf['template_force_compile'] = false;
+
 // this permit to show the php errors reporting (see INI 'error_reporting'
 // for possible values)
 // gives an empty value '' to deactivate
@@ -503,11 +514,14 @@ $conf['apache_authentication'] = false;
 // piwigo_users table.
 $conf['users_table'] = $prefixeTable.'users';
 
+// If you decide to use external authentication 
+// change conf below by $conf['external_authentification'] = true;
+$conf['external_authentification'] = false;
+
 // Other tables can be changed, if you define associated constants
 // Example:
 //   define('USER_INFOS_TABLE', 'pwg_main'.'user_infos');
 
-
 // user_fields : mapping between generic field names and table specific
 // field names. For example, in PWG, the mail address is names
 // "mail_address" and in punbb, it's called "email".
@@ -664,7 +678,7 @@ $conf['rss_feed_author'] = 'Piwigo notifier';
 // | Set admin layout                                                      |
 // +-----------------------------------------------------------------------+
 
-$conf['admin_layout'] = 'goto/roma';
+$conf['admin_theme'] = 'roma';
 
 // should we load the active plugins ? true=Yes, false=No
 $conf['enable_plugins']=true;
@@ -748,6 +762,26 @@ $conf['light_slideshow'] = true;
 // or other plugin variables etc
 $conf['local_data_dir'] = dirname(dirname(__FILE__)).'/_data';
 
-// where should the API add photos?
-$conf['upload_dir'] = PHPWG_ROOT_PATH.'upload';
+// where should the API/UploadForm add photos? This path must be relative to
+// the Piwigo installation directory (but can be outside, as long as it's
+// reachable from your webserver).
+$conf['upload_dir'] = './upload';
+
+// where should the user be guided when there is no photo in his gallery yet?
+$conf['no_photo_yet_url'] = 'admin.php?page=photos_add';
+
+// directory with themes inside
+$conf['themes_dir'] = PHPWG_ROOT_PATH.'themes';
+
+// pLoader direct download url for windows
+$conf['ploader_download_windows'] = 'http://piwigo.org/ext/download.php?eid=270';
+
+// pLoader direct download url for mac
+$conf['ploader_download_mac'] = 'http://piwigo.org/ext/download.php?eid=353';
+
+// pLoader direct download url for linux
+$conf['ploader_download_linux'] = 'http://piwigo.org/ext/download.php?eid=269';
+
+// enable the synchronization method for adding photos
+$conf['enable_synchronization'] = true;
 ?>
