@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -32,66 +32,17 @@ include_once( PHPWG_ROOT_PATH .'include/functions_url.inc.php' );
 include_once( PHPWG_ROOT_PATH .'include/functions_plugins.inc.php' );
 
 //----------------------------------------------------------- generic functions
-
-/**
- * returns an array containing the possible values of an enum field
- *
- * @param string tablename
- * @param string fieldname
- */
-function get_enums($table, $field)
+function get_extra_fields($order_by_fields)
 {
-  // retrieving the properties of the table. Each line represents a field :
-  // columns are 'Field', 'Type'
-  $result = pwg_query('desc '.$table);
-  while ($row = mysql_fetch_array($result))
+  $fields = str_ireplace(array(' order by ', ' desc', ' asc'),
+			 array('', '', ''),
+			 $order_by_fields
+			 );
+  if (!empty($fields))
   {
-    // we are only interested in the the field given in parameter for the
-    // function
-    if ($row['Field'] == $field)
-    {
-      // retrieving possible values of the enum field
-      // enum('blue','green','black')
-      $options = explode(',', substr($row['Type'], 5, -1));
-      foreach ($options as $i => $option)
-      {
-        $options[$i] = str_replace("'", '',$option);
-      }
-    }
-  }
-  mysql_free_result($result);
-  return $options;
-}
-
-// get_boolean transforms a string to a boolean value. If the string is
-// "false" (case insensitive), then the boolean value false is returned. In
-// any other case, true is returned.
-function get_boolean( $string )
-{
-  $boolean = true;
-  if ( 'false' == strtolower($string) )
-  {
-    $boolean = false;
-  }
-  return $boolean;
-}
-
-/**
- * returns boolean string 'true' or 'false' if the given var is boolean
- *
- * @param mixed $var
- * @return mixed
- */
-function boolean_to_string($var)
-{
-  if (is_bool($var))
-  {
-    return $var ? 'true' : 'false';
-  }
-  else
-  {
-    return $var;
+    $fields = ','.$fields;
   }
+  return $fields;
 }
 
 // The function get_moment returns a float value coresponding to the number
@@ -217,12 +168,16 @@ function mkgetdir($dir, $flags=MKGETDIR_DEFAULT)
 {
   if ( !is_dir($dir) )
   {
+    if (substr(PHP_OS, 0, 3) == 'WIN')
+    {
+      $dir = str_replace('/', DIRECTORY_SEPARATOR, $dir);
+    }
     $umask = umask(0);
     $mkd = @mkdir($dir, 0755, ($flags&MKGETDIR_RECURSIVE) ? true:false );
     umask($umask);
     if ($mkd==false)
     {
-      !($flags&MKGETDIR_DIE_ON_ERROR) or fatal_error( "$dir ".l10n('no_write_access'));
+      !($flags&MKGETDIR_DIE_ON_ERROR) or fatal_error( "$dir ".l10n('no write access'));
       return false;
     }
     if( $flags&MKGETDIR_PROTECT_HTACCESS )
@@ -238,7 +193,7 @@ function mkgetdir($dir, $flags=MKGETDIR_DEFAULT)
   }
   if ( !is_writable($dir) )
   {
-    !($flags&MKGETDIR_DIE_ON_ERROR) or fatal_error( "$dir ".l10n('no_write_access'));
+    !($flags&MKGETDIR_DIE_ON_ERROR) or fatal_error( "$dir ".l10n('no write access'));
     return false;
   }
   return true;
@@ -256,11 +211,13 @@ function mkgetdir($dir, $flags=MKGETDIR_DEFAULT)
  */
 function mkget_thumbnail_dir($dirname, &$errors)
 {
-  $tndir = $dirname.'/thumbnail';
+  global $conf;
+
+  $tndir = $dirname.'/'.$conf['dir_thumbnail'];
   if (! mkgetdir($tndir, MKGETDIR_NONE) )
   {
     array_push($errors,
-          '['.$dirname.'] : '.l10n('no_write_access'));
+          '['.$dirname.'] : '.l10n('no write access'));
     return false;
   }
   return $tndir;
@@ -428,11 +385,18 @@ function remove_accents($string)
  */
 function str2url($str)
 {
+  $raw = $str;
+
   $str = remove_accents($str);
   $str = preg_replace('/[^a-z0-9_\s\'\:\/\[\],-]/','',strtolower($str));
   $str = preg_replace('/[\s\'\:\/\[\],-]+/',' ',trim($str));
   $res = str_replace(' ','_',$str);
 
+  if (empty($res))
+  {
+    $res = $raw;
+  }
+
   return $res;
 }
 
@@ -443,55 +407,23 @@ function str2url($str)
  *
  * @returns array
  */
-function get_languages($target_charset = null)
+function get_languages()
 {
-  if ( empty($target_charset) )
-  {
-    $target_charset = get_pwg_charset();
-  }
-  $target_charset = strtolower($target_charset);
+  $query = '
+SELECT id, name
+  FROM '.LANGUAGES_TABLE.'
+  ORDER BY name ASC
+;';
+  $result = pwg_query($query);
 
-  $dir = opendir(PHPWG_ROOT_PATH.'language');
   $languages = array();
-
-  while ($file = readdir($dir))
+  while ($row = pwg_db_fetch_assoc($result))
   {
-    $path = PHPWG_ROOT_PATH.'language/'.$file;
-    if (!is_link($path) and is_dir($path) and file_exists($path.'/iso.txt'))
+    if (is_dir(PHPWG_ROOT_PATH.'language/'.$row['id']))
     {
-      list($language_name) = @file($path.'/iso.txt');
-
-      $langdef = explode('.',$file);
-      if (count($langdef)>1) // (langCode,encoding)
-      {
-        $langdef[1] = strtolower($langdef[1]);
-
-        if (
-          $target_charset==$langdef[1]
-         or
-          ($target_charset=='utf-8' and $langdef[1]=='iso-8859-1')
-         or
-          ($target_charset=='iso-8859-1' and
-          in_array( substr($langdef[0],2), array('en','fr','de','es','it','nl')))
-        )
-        {
-          $language_name = convert_charset($language_name,
-              $langdef[1], $target_charset);
-          $languages[ $langdef[0] ] = $language_name;
-        }
-        else
-          continue; // the language encoding is not compatible with our charset
-      }
-      else
-      { // UTF-8
-        $language_name = convert_charset($language_name,
-              'utf-8', $target_charset);
-        $languages[$file] = $language_name;
-      }
+      $languages[ $row['id'] ] = $row['name'];
     }
   }
-  closedir($dir);
-  @asort($languages);
 
   return $languages;
 }
@@ -538,8 +470,8 @@ INSERT INTO '.HISTORY_TABLE.'
   )
   VALUES
   (
-    CURDATE(),
-    CURTIME(),
+    CURRENT_DATE,
+    CURRENT_TIME,
     '.$user['id'].',
     \''.$_SERVER['REMOTE_ADDR'].'\',
     '.(isset($page['section']) ? "'".$page['section']."'" : 'NULL').',
@@ -599,54 +531,6 @@ function format_date($date, $show_time = false)
   return $formated_date;
 }
 
-function pwg_query($query)
-{
-  global $conf,$page,$debug,$t2;
-
-  $start = get_moment();
-  ($result = mysql_query($query)) or my_error($query, $conf['die_on_sql_error']);
-
-  $time = get_moment() - $start;
-
-  if (!isset($page['count_queries']))
-  {
-    $page['count_queries'] = 0;
-    $page['queries_time'] = 0;
-  }
-
-  $page['count_queries']++;
-  $page['queries_time']+= $time;
-
-  if ($conf['show_queries'])
-  {
-    $output = '';
-    $output.= '<pre>['.$page['count_queries'].'] ';
-    $output.= "\n".$query;
-    $output.= "\n".'(this query time : ';
-    $output.= '<b>'.number_format($time, 3, '.', ' ').' s)</b>';
-    $output.= "\n".'(total SQL time  : ';
-    $output.= number_format($page['queries_time'], 3, '.', ' ').' s)';
-    $output.= "\n".'(total time      : ';
-    $output.= number_format( ($time+$start-$t2), 3, '.', ' ').' s)';
-    if ( $result!=null and preg_match('/\s*SELECT\s+/i',$query) )
-    {
-      $output.= "\n".'(num rows        : ';
-      $output.= mysql_num_rows($result).' )';
-    }
-    elseif ( $result!=null
-      and preg_match('/\s*INSERT|UPDATE|REPLACE|DELETE\s+/i',$query) )
-    {
-      $output.= "\n".'(affected rows   : ';
-      $output.= mysql_affected_rows().' )';
-    }
-    $output.= "</pre>\n";
-
-    $debug .= $output;
-  }
-
-  return $result;
-}
-
 function pwg_debug( $string )
 {
   global $debug,$t2,$page;
@@ -704,18 +588,17 @@ function redirect_html( $url , $msg = '', $refresh_time = 0)
     $user = build_user( $conf['guest_id'], true);
     load_language('common.lang');
     trigger_action('loading_lang');
-    load_language('local.lang', '', array('no_fallback'=>true) );
-    list($tmpl, $thm) = explode('/', get_default_template());
-    $template = new Template(PHPWG_ROOT_PATH.'template/'.$tmpl, $thm);
+    load_language('lang', PHPWG_ROOT_PATH.'local/', array('no_fallback'=>true, 'local'=>true) );
+    $template = new Template(PHPWG_ROOT_PATH.'themes', get_default_theme());
   }
   else
   {
-    $template = new Template(PHPWG_ROOT_PATH.'template/'.$user['template'], $user['theme']);
+    $template = new Template(PHPWG_ROOT_PATH.'themes', $user['theme']);
   }
 
   if (empty($msg))
   {
-    $msg = nl2br(l10n('redirect_msg'));
+    $msg = nl2br(l10n('Redirection...'));
   }
 
   $refresh = $refresh_time;
@@ -804,27 +687,43 @@ function url_is_remote($url)
 }
 
 /**
- * returns available template/theme
+ * returns available themes
  */
 function get_pwg_themes()
 {
   global $conf;
+
   $themes = array();
 
-  $template_dir = PHPWG_ROOT_PATH.'template';
-
-  foreach (get_dirs($template_dir) as $template)
+  $query = '
+SELECT
+    id,
+    name
+  FROM '.THEMES_TABLE.'
+  ORDER BY name ASC
+;';
+  $result = pwg_query($query);
+  while ($row = pwg_db_fetch_assoc($result))
   {
-    foreach (get_dirs($template_dir.'/'.$template.'/theme') as $theme)
+    if (check_theme_installed($row['id']))
     {
-      if ( ($template.'/'.$theme) != $conf['admin_layout'] )
-      array_push($themes, $template.'/'.$theme);
+      $themes[ $row['id'] ] = $row['name'];
     }
   }
 
+  // plugins want remove some themes based on user status maybe?
+  $themes = trigger_event('get_pwg_themes', $themes);
+
   return $themes;
 }
 
+function check_theme_installed($theme_id)
+{
+  global $conf;
+
+  return file_exists($conf['themes_dir'].'/'.$theme_id.'/'.'themeconf.inc.php');
+}
+
 /* Returns the PATH to the thumbnail to be displayed. If the element does not
  * have a thumbnail, the default mime image path is returned. The PATH can be
  * used in the php script, but not sent to the browser.
@@ -870,7 +769,7 @@ function get_thumbnail_location($element_info)
   {
     $path = substr_replace(
       get_filename_wo_extension($element_info['path']),
-      '/thumbnail/'.$conf['prefix_thumbnail'],
+      '/'.$conf['dir_thumbnail'].'/'.$conf['prefix_thumbnail'],
       strrpos($element_info['path'],'/'),
       1
       );
@@ -908,44 +807,6 @@ function get_thumbnail_title($element_info)
   return $thumbnail_title;
 }
 
-// my_error returns (or send to standard output) the message concerning the
-// error occured for the last mysql query.
-function my_error($header, $die)
-{
-  $error = "[mysql error ".mysql_errno().'] '.mysql_error()."\n";
-  $error .= $header;
-
-  if ($die)
-  {
-    fatal_error($error);
-  }
-  echo("<pre>");
-  trigger_error($error, E_USER_WARNING);
-  echo("</pre>");
-}
-
-
-/**
- * creates an array based on a query, this function is a very common pattern
- * used here
- *
- * @param string $query
- * @param string $fieldname
- * @return array
- */
-function array_from_query($query, $fieldname)
-{
-  $array = array();
-
-  $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
-  {
-    array_push($array, $row[$fieldname]);
-  }
-
-  return $array;
-}
-
 /**
  * fill the current user caddie with given elements, if not already in
  * caddie
@@ -999,7 +860,7 @@ function get_name_from_file($filename)
  * @param string key
  * @return string
  */
-function l10n($key)
+function l10n($key, $textdomain='messages')
 {
   global $lang, $conf;
 
@@ -1032,6 +893,7 @@ function l10n_dec($singular_fmt_key, $plural_fmt_key, $decimal)
           : $singular_fmt_key
         )), $decimal);
 }
+
 /*
  * returns a single element to use with l10n_args
  *
@@ -1124,7 +986,7 @@ SELECT '.$conf['user_fields']['email'].'
   FROM '.USERS_TABLE.'
   WHERE '.$conf['user_fields']['id'].' = '.$conf['webmaster_id'].'
 ;';
-  list($email) = mysql_fetch_array(pwg_query($query));
+  list($email) = pwg_db_fetch_row(pwg_query($query));
 
   return $email;
 }
@@ -1145,12 +1007,12 @@ SELECT param, value
 ;';
   $result = pwg_query($query);
 
-  if ((mysql_num_rows($result) == 0) and !empty($condition))
+  if ((pwg_db_num_rows($result) == 0) and !empty($condition))
   {
     fatal_error('No configuration data');
   }
 
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $conf[ $row['param'] ] = isset($row['value']) ? $row['value'] : '';
 
@@ -1163,6 +1025,24 @@ SELECT param, value
   }
 }
 
+function conf_update_param($param, $value)
+{
+  $query = '
+DELETE
+  FROM '.CONFIG_TABLE.'
+  WHERE param = \''.$param.'\'
+;';
+  pwg_query($query);
+
+  $query = '
+INSERT
+  INTO '.CONFIG_TABLE.'
+  (param, value)
+  VALUES(\''.$param.'\', \''.$value.'\')
+;';
+  pwg_query($query);
+}
+
 /**
  * Prepends and appends a string at each value of the given array.
  *
@@ -1195,7 +1075,7 @@ function simple_hash_from_query($query, $keyname, $valuename)
   $array = array();
 
   $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $array[ $row[$keyname] ] = $row[$valuename];
   }
@@ -1216,7 +1096,7 @@ function hash_from_query($query, $keyname)
 {
   $array = array();
   $result = pwg_query($query);
-  while ($row = mysql_fetch_assoc($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $array[ $row[$keyname] ] = $row;
   }
@@ -1286,8 +1166,12 @@ function get_filter_page_value($value_name)
  */
 function get_pwg_charset()
 {
-  defined('PWG_CHARSET') or fatal_error('PWG_CHARSET undefined');
-  return PWG_CHARSET;
+  $pwg_charset = 'utf-8';
+  if (defined('PWG_CHARSET'))
+  {
+    $pwg_charset = PWG_CHARSET;
+  }
+  return $pwg_charset;
 }
 
 /**
@@ -1305,6 +1189,7 @@ function get_pwg_charset()
  *     return - if true the file content is returned otherwise the file is evaluated as php
  *     target_charset -
  *     no_fallback - the language must be respected
+ *     local - if true, get local language file
  * @return boolean success status or a string if options['return'] is true
  */
 function load_language($filename, $dirname = '',
@@ -1351,28 +1236,15 @@ function load_language($filename, $dirname = '',
     $target_charset = $options['target_charset'];
   }
   $target_charset = strtolower($target_charset);
-  $source_charset = '';
   $source_file    = '';
   foreach ($languages as $language)
   {
-    $dir = $dirname.$language;
+    $f = @$options['local'] ?
+      $dirname.$language.'.'.$filename:
+      $dirname.$language.'/'.$filename;
 
-    if ($target_charset!='utf-8')
-    {
-      // exact charset match - no conversion required
-      $f = $dir.'.'.$target_charset.'/'.$filename;
-      if (file_exists($f))
-      {
-        $source_file = $f;
-        break;
-      }
-    }
-
-    // UTF-8 ?
-    $f = $dir.'/'.$filename;
     if (file_exists($f))
     {
-      $source_charset = 'utf-8';
       $source_file = $f;
       break;
     }
@@ -1390,7 +1262,7 @@ function load_language($filename, $dirname = '',
       if ( !isset($lang) ) $lang=array();
       if ( !isset($lang_info) ) $lang_info=array();
 
-      if ( !empty($source_charset) and $source_charset!=$target_charset)
+      if ( 'utf-8'!=$target_charset)
       {
         if ( is_array($load_lang) )
         {
@@ -1398,18 +1270,18 @@ function load_language($filename, $dirname = '',
           {
             if ( is_array($v) )
             {
-              $func = create_function('$v', 'return convert_charset($v, "'.$source_charset.'","'.$target_charset.'");' );
+              $func = create_function('$v', 'return convert_charset($v, "utf-8", "'.$target_charset.'");' );
               $lang[$k] = array_map($func, $v);
             }
             else
-              $lang[$k] = convert_charset($v, $source_charset, $target_charset);
+              $lang[$k] = convert_charset($v, 'utf-8', $target_charset);
           }
         }
         if ( is_array($load_lang_info) )
         {
           foreach ($load_lang_info as $k => $v)
           {
-            $lang_info[$k] = convert_charset($v, $source_charset, $target_charset);
+            $lang_info[$k] = convert_charset($v, 'utf-8', $target_charset);
           }
         }
       }
@@ -1423,10 +1295,7 @@ function load_language($filename, $dirname = '',
     else
     {
       $content = @file_get_contents($source_file);
-      if ( !empty($source_charset) and $source_charset!=$target_charset)
-      {
-        $content = convert_charset($content, $source_charset, $target_charset);
-      }
+      $content = convert_charset($content, 'utf-8', $target_charset);
       return $content;
     }
   }
@@ -1498,6 +1367,129 @@ function get_comment_post_key($image_id)
     );
 }
 
+/**
+ * return an array which will be sent to template to display navigation bar
+ */
+function create_navigation_bar($url, $nb_element, $start, $nb_element_page, $clean_url = false)
+{
+  global $conf;
+
+  $navbar = array();
+  $pages_around = $conf['paginate_pages_around'];
+  $start_str = $clean_url ? '/start-' : (strpos($url, '?')===false ? '?':'&amp;').'start=';
+
+  if (!isset($start) or !is_numeric($start) or (is_numeric($start) and $start < 0))
+  {
+    $start = 0;
+  }
+
+  // navigation bar useful only if more than one page to display !
+  if ($nb_element > $nb_element_page)
+  {
+    $cur_page = ceil($start / $nb_element_page) + 1;
+    $maximum = ceil($nb_element / $nb_element_page);
+    $previous = $start - $nb_element_page;
+    $next = $start + $nb_element_page;
+    $last = ($maximum - 1) * $nb_element_page;
+
+    $navbar['CURRENT_PAGE'] = $cur_page;
+
+    // link to first page and previous page?
+    if ($cur_page != 1)
+    {
+      $navbar['URL_FIRST'] = $url;
+      $navbar['URL_PREV'] = $url.($previous > 0 ? $start_str.$previous : '');
+    }
+    // link on next page and last page?
+    if ($cur_page != $maximum)
+    {
+      $navbar['URL_NEXT'] = $url.$start_str.$next;
+      $navbar['URL_LAST'] = $url.$start_str.$last;
+    }
+
+    // pages to display
+    $navbar['pages'] = array();
+    $navbar['pages'][1] = $url;
+    $navbar['pages'][$maximum] = $url.$start_str.$last;
+
+    for ($i = max($cur_page - $pages_around , 2), $stop = min($cur_page + $pages_around + 1, $maximum);
+         $i < $stop; $i++)
+    {
+      $navbar['pages'][$i] = $url.$start_str.(($i - 1) * $nb_element_page);
+    }
+    ksort($navbar['pages']);
+  }
+  return $navbar;
+}
+
+/**
+ * return an array which will be sent to template to display recent icon
+ */
+function get_icon($date, $is_child_date = false)
+{
+  global $cache, $user;
+
+  if (empty($date))
+  {
+    return false;
+  }
+
+  if (!isset($cache['get_icon']['title']))
+  {
+    $cache['get_icon']['title'] = sprintf(
+      l10n('images posted during the last %d days'),
+      $user['recent_period']
+      );
+  }
+
+  $icon = array(
+    'TITLE' => $cache['get_icon']['title'],
+    'IS_CHILD_DATE' => $is_child_date,
+    );
+
+  if (isset($cache['get_icon'][$date]))
+  {
+    return $cache['get_icon'][$date] ? $icon : array();
+  }
+
+  if (!isset($cache['get_icon']['sql_recent_date']))
+  {
+    // Use MySql date in order to standardize all recent "actions/queries"
+    $cache['get_icon']['sql_recent_date'] = pwg_db_get_recent_period($user['recent_period']);
+  }
+
+  $cache['get_icon'][$date] = $date > $cache['get_icon']['sql_recent_date'];
+
+  return $cache['get_icon'][$date] ? $icon : array();
+}
+
+/**
+ * check token comming from form posted or get params to prevent csrf attacks
+ * if pwg_token is empty action doesn't require token
+ * else pwg_token is compare to server token
+ *
+ * @return void access denied if token given is not equal to server token
+ */
+function check_pwg_token()
+{
+  if (!empty($_REQUEST['pwg_token']))
+  {
+    if (get_pwg_token() != $_REQUEST['pwg_token'])
+    {
+      access_denied();
+    }
+  }
+  else
+    bad_request('missing token');
+}
+
+function get_pwg_token()
+{
+  global $conf;
+
+  return hash_hmac('md5', session_id(), $conf['secret_key']);
+}
+
 /*
  * breaks the script execution if the given value doesn't match the given
  * pattern. This should happen only during hacking attempts.
@@ -1547,36 +1539,45 @@ function check_input_parameter($param_name, $param_array, $is_array, $pattern)
   }
 }
 
-/**
- * check token comming from form posted or get params to prevent csrf attacks
- * if pwg_token is empty action doesn't require token
- * else pwg_token is compare to server token
- *
- * @return void access denied if token given is not equal to server token
- */
-function check_pwg_token()
-{
-  $valid_token = get_pwg_token();
-  $given_token = null;
 
-  if (!empty($_POST['pwg_token']))
-  {
-    $given_token = $_POST['pwg_token'];
-  }
-  elseif (!empty($_GET['pwg_token']))
-  {
-    $given_token = $_GET['pwg_token'];
-  }
-  if ($given_token != $valid_token)
-  {
-    access_denied();
-  }
-}
-
-function get_pwg_token()
+function get_privacy_level_options()
 {
   global $conf;
 
-  return hash_hmac('md5', session_id(), $conf['secret_key']);
+  $options = array();
+  foreach (array_reverse($conf['available_permission_levels']) as $level)
+  {
+    $label = null;
+
+    if (0 == $level)
+    {
+      $label = l10n('Everybody');
+    }
+    else
+    {
+      $labels = array();
+      $sub_levels = array_reverse($conf['available_permission_levels']);
+      foreach ($sub_levels as $sub_level)
+      {
+        if ($sub_level == 0 or $sub_level < $level)
+        {
+          break;
+        }
+        array_push(
+          $labels,
+          l10n(
+            sprintf(
+              'Level %d',
+              $sub_level
+              )
+            )
+          );
+      }
+
+      $label = implode(', ', $labels);
+    }
+    $options[$level] = $label;
+  }
+  return $options;
 }
 ?>
\ No newline at end of file
