@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -150,38 +150,6 @@ function get_strict_email_list($email_list)
   return implode(',', $result);
 }
 
-/**
- * Returns an completed array template/theme
- * completed with get_default_template()
- *
- * @params:
- *   - args: incompleted array of template/theme
- *       o template: template to use [default get_default_template()]
- *       o theme: template to use [default get_default_template()]
- */
-function get_array_template_theme($args = array())
-{
-  global $conf;
-
-  $res = array();
-
-  if (empty($args['template']) or empty($args['theme']))
-  {
-    list($res['template'], $res['theme']) = explode('/', get_default_template());
-  }
-
-  if (!empty($args['template']))
-  {
-    $res['template'] = $args['template'];
-  }
-
-  if (!empty($args['theme']))
-  {
-    $res['theme'] = $args['theme'];
-  }
-
-  return $res;
-}
 
 /**
  * Return an new mail template
@@ -189,15 +157,18 @@ function get_array_template_theme($args = array())
  * @params:
  *   - email_format: mail format
  *   - args: function params of mail function:
- *       o template: template to use [default get_default_template()]
- *       o theme: template to use [default get_default_template()]
+ *       o template: template to use [default get_default_theme()]
+ *       o theme: template to use [default get_default_theme()]
  */
-function & get_mail_template($email_format, $args = array())
+function & get_mail_template($email_format, $theme='')
 {
-  $args = get_array_template_theme($args);
+  if (empty($theme))
+  {
+    $theme = get_default_theme();
+  }
+
+  $mail_template = new Template(PHPWG_ROOT_PATH.'themes', $theme, 'template/mail/'.$email_format);
 
-  $mail_template = new Template(PHPWG_ROOT_PATH.'template/'.$args['template'], $args['theme']);
-  $mail_template->set_template_dir(PHPWG_ROOT_PATH.'template/'.$args['template'].'/mail/'.$email_format);
   return $mail_template;
 }
 
@@ -252,7 +223,9 @@ function switch_lang_to($language)
     // Translations are in admin file too
     load_language('admin.lang', '', array('language'=>$language) );
     trigger_action('loading_lang');
-    load_language('local.lang', '', array('language'=>$language, 'no_fallback'=>true));
+    load_language('lang', PHPWG_ROOT_PATH.'local/',
+      array('language'=>$language, 'no_fallback'=>true, 'local'=>true)
+    );
 
     $switch_lang['language'][$language]['lang_info'] = $lang_info;
     $switch_lang['language'][$language]['lang'] = $lang;
@@ -341,7 +314,7 @@ order by
   $datas = pwg_query($query);
   if (!empty($datas))
   {
-    while ($admin = mysql_fetch_array($datas))
+    while ($admin = pwg_db_fetch_assoc($datas))
     {
       if (!empty($admin['mail_address']))
       {
@@ -354,7 +327,7 @@ order by
   {
     $keyargs_content_admin_info = array
     (
-      get_l10n_args('Connected user: %s', $user['username']),
+      get_l10n_args('Connected user: %s', stripslashes($user['username'])),
       get_l10n_args('IP: %s', $_SERVER['REMOTE_ADDR']),
       get_l10n_args('Browser: %s', $_SERVER['HTTP_USER_AGENT'])
     );
@@ -417,7 +390,7 @@ function pwg_mail_group(
 
   $query = '
 SELECT
-  distinct language, template
+  distinct language, theme
 FROM
   '.USER_GROUP_TABLE.' as ug
   INNER JOIN '.USERS_TABLE.' as u  ON '.$conf['user_fields']['id'].' = ug.user_id
@@ -437,13 +410,11 @@ WHERE
 
   $result = pwg_query($query);
 
-  if (mysql_num_rows($result) > 0)
+  if (pwg_db_num_rows($result) > 0)
   {
     $list = array();
-    while ($row = mysql_fetch_array($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
-      $row['template_theme'] = $row['template'];
-      list($row['template'], $row['theme']) = explode('/', $row['template_theme']);
       $list[] = $row;
     }
 
@@ -461,19 +432,19 @@ WHERE
         '.$conf['user_fields']['email'].' IS NOT NULL
     AND group_id = '.$group_id.'
     AND language = \''.$elem['language'].'\'
-    AND template = \''.$elem['template_theme'].'\'
+    AND theme = \''.$elem['theme'].'\'
 ;';
 
       $result = pwg_query($query);
 
-      if (mysql_num_rows($result) > 0)
+      if (pwg_db_num_rows($result) > 0)
       {
         $Bcc = array();
-        while ($row = mysql_fetch_array($result))
+        while ($row = pwg_db_fetch_assoc($result))
         {
           if (!empty($row['mail_address']))
           {
-            array_push($Bcc, format_email($row['username'], $row['mail_address']));
+            array_push($Bcc, format_email(stripslashes($row['username']), $row['mail_address']));
           }
         }
 
@@ -481,7 +452,7 @@ WHERE
         {
           switch_lang_to($elem['language']);
 
-          $mail_template = get_mail_template($email_format, $elem);
+          $mail_template = get_mail_template($email_format, $elem['theme']);
           $mail_template->set_filename($tpl_shortname, $tpl_shortname.'.tpl');
 
           $mail_template->assign(
@@ -497,7 +468,6 @@ WHERE
               'email_format' => $email_format,
               'content' => $mail_template->parse($tpl_shortname, true),
               'content_format' => $email_format,
-              'template' => $elem['template'],
               'theme' => $elem['theme']
             )
           ) and $return;
@@ -524,8 +494,7 @@ WHERE
  *       o content: content of mail    [default value '']
  *       o content_format: format of mail content  [default value 'text/plain']
  *       o email_format: global mail format  [default value $conf_mail['default_email_format']]
- *       o template: template to use [default get_default_template()]
- *       o theme: template to use [default get_default_template()]
+ *       o theme: template to use [default get_default_theme()]
  *
  * @return boolean (Ok or not)
  */
@@ -584,7 +553,10 @@ function pwg_mail($to, $args = array())
     $args['Bcc'][] = $conf_mail['formated_email_webmaster'];
   }
 
-  $args = array_merge($args, get_array_template_theme($args));
+  if (empty($args['theme']))
+  {
+    $args['theme'] = get_default_theme();
+  }
 
   $headers = 'From: '.$args['from']."\n";
   $headers.= 'Reply-To: '.$args['from']."\n";
@@ -617,19 +589,19 @@ function pwg_mail($to, $args = array())
   foreach (array_unique($content_type_list) as $content_type)
   {
     // key compose of indexes witch allow ti cache mail data
-    $cache_key = $content_type.'-'.$lang_info['code'].'-'.$args['template'].'-'.$args['theme'];
+    $cache_key = $content_type.'-'.$lang_info['code'].'-'.$args['theme'];
 
     if (!isset($conf_mail[$cache_key]))
     {
-      if (!isset($conf_mail[$cache_key]['template']))
+      if (!isset($conf_mail[$cache_key]['theme']))
       {
-        $conf_mail[$cache_key]['template'] = get_mail_template($content_type);
+        $conf_mail[$cache_key]['theme'] = get_mail_template($content_type, $args['theme']);
       }
 
-      $conf_mail[$cache_key]['template']->set_filename('mail_header', 'header.tpl');
-      $conf_mail[$cache_key]['template']->set_filename('mail_footer', 'footer.tpl');
+      $conf_mail[$cache_key]['theme']->set_filename('mail_header', 'header.tpl');
+      $conf_mail[$cache_key]['theme']->set_filename('mail_footer', 'footer.tpl');
 
-      $conf_mail[$cache_key]['template']->assign(
+      $conf_mail[$cache_key]['theme']->assign(
         array(
           //Header
           'BOUNDARY_KEY' => $conf_mail['boundary_key'],
@@ -637,51 +609,40 @@ function pwg_mail($to, $args = array())
           'CONTENT_ENCODING' => get_pwg_charset(),
 
           // Footer
-          'GALLERY_URL' =>
-            isset($page['gallery_url']) ?
-                  $page['gallery_url'] : $conf['gallery_url'],
+          'GALLERY_URL' => get_gallery_home_url(),
           'GALLERY_TITLE' =>
             isset($page['gallery_title']) ?
                   $page['gallery_title'] : $conf['gallery_title'],
           'VERSION' => $conf['show_version'] ? PHPWG_VERSION : '',
           'PHPWG_URL' => PHPWG_URL,
 
-          'TITLE_MAIL' => urlencode(l10n('title_send_mail')),
+          'TITLE_MAIL' => urlencode(l10n('A comment on your site')),
           'MAIL' => get_webmaster_mail_address()
           ));
 
       if ($content_type == 'text/html')
       {
-        if (is_file($conf_mail[$cache_key]['template']->get_template_dir().'/global-mail-css.tpl'))
+        if ($conf_mail[$cache_key]['theme']->smarty->template_exists('global-mail-css.tpl'))
         {
-          $conf_mail[$cache_key]['template']->set_filename('css', 'global-mail-css.tpl');
-          $conf_mail[$cache_key]['template']->assign_var_from_handle('GLOBAL_MAIL_CSS', 'css');
+          $conf_mail[$cache_key]['theme']->set_filename('css', 'global-mail-css.tpl');
+          $conf_mail[$cache_key]['theme']->assign_var_from_handle('GLOBAL_MAIL_CSS', 'css');
         }
 
-        $root_abs_path = dirname(dirname(__FILE__));
-
-        $file = $root_abs_path.'/template/'.$args['template'].'/theme/'.$args['theme'].'/mail-css.tpl';
+        $file = PHPWG_ROOT_PATH.'themes/'.$args['theme'].'/mail-css.tpl';
         if (is_file($file))
         {
-          $conf_mail[$cache_key]['template']->set_filename('css', $file);
-          $conf_mail[$cache_key]['template']->assign_var_from_handle('MAIL_CSS', 'css');
-        }
-
-        $file = $root_abs_path.'/template-common/local-mail-css.tpl';
-        if (is_file($file))
-        {
-          $conf_mail[$cache_key]['template']->set_filename('css', $file);
-          $conf_mail[$cache_key]['template']->assign_var_from_handle('LOCAL_MAIL_CSS', 'css');
+          $conf_mail[$cache_key]['theme']->set_filename('css', realpath($file));
+          $conf_mail[$cache_key]['theme']->assign_var_from_handle('MAIL_CSS', 'css');
         }
       }
 
       // what are displayed on the header of each mail ?
       $conf_mail[$cache_key]['header'] =
-        $conf_mail[$cache_key]['template']->parse('mail_header', true);
+        $conf_mail[$cache_key]['theme']->parse('mail_header', true);
 
       // what are displayed on the footer of each mail ?
       $conf_mail[$cache_key]['footer'] =
-        $conf_mail[$cache_key]['template']->parse('mail_footer', true);
+        $conf_mail[$cache_key]['theme']->parse('mail_footer', true);
     }
 
     // Header
@@ -714,7 +675,6 @@ function pwg_mail($to, $args = array())
   $content.= "\n".'-----='.$conf_mail['boundary_key'].'--'."\n";
   }
 
-
   //~ // Close boundary
   //~ $content.= "\n".'-----='.$conf_mail['boundary_key'].'--'."\n";
 
@@ -777,14 +737,70 @@ function pwg_send_mail($result, $to, $subject, $content, $headers)
   }
 }
 
+function move_ccs_rules_to_body($content)
+{
+  // We search all css rules in style tags
+  preg_match('#<style>(.*?)</style>#s', $content, $matches);
+
+  if (!empty($matches[1]))
+  {
+    preg_match_all('#([^\n]*?)\{(.*?)\}#s', $matches[1], $matches);
+
+    $selectors = array();
+    $unknow_selectors = '';
+
+    foreach ($matches[1] as $key => $value)
+    {
+      $selects = explode(',', $value);
+      $style = trim($matches[2][$key], ' ;');
+
+      foreach($selects as $select)
+      {
+        $select = trim($select);
+        $selectors[$select][] = $style;
+      }
+    }
+    foreach ($selectors as $selector => $style)
+    {
+      if (!preg_match('/^(#|\.|)([A-Za-z0-9_-]*)$/', $selector, $matches))
+      {
+        $unknow_selectors .= $selector.' {'.implode('; ', $style).";}\n";
+      }
+      else switch ($matches[1])
+      {
+        case '#':
+          $content = preg_replace('|id="'.$matches[2].'"|', 'id="'.$matches[2].'" style="'.implode('; ', $style).';"', $content);
+          break;
+        case '.':
+          $content = preg_replace('|class="'.$matches[2].'"|', 'class="'.$matches[2].'" style="'.implode('; ', $style).';"', $content);
+          break;
+        default:
+          $content = preg_replace('#<'.$matches[2].'( |>)#', '<'.$matches[2].' style="'.implode('; ', $style).';"$1', $content);
+          break;
+      }
+    }
+
+    // Keep unknow tags in page head
+    if (!empty($unknow_selectors))
+    {
+      $content = preg_replace('#<style>.*?</style>#s', "<style type=\"text/css\">\n$unknow_selectors</style>", $content);
+    }
+    else
+    {
+      $content = preg_replace('#<style>.*?</style>#s', '', $content);
+    }
+  }
+  return $content;
+}
+
 /*Testing block*/
-/*function pwg_send_mail_test($result, $to, $subject, $content, $headers, $args)
+function pwg_send_mail_test($result, $to, $subject, $content, $headers, $args)
 {
     global $conf, $user, $lang_info;
     $dir = $conf['local_data_dir'].'/tmp';
     if ( mkgetdir( $dir,  MKGETDIR_DEFAULT&~MKGETDIR_DIE_ON_ERROR) )
     {
-      $filename = $dir.'/mail.'.$user['username'].'.'.$lang_info['code'].'.'.$args['template'].'.'.$args['theme'];
+      $filename = $dir.'/mail.'.stripslashes($user['username']).'.'.$lang_info['code'].'.'.$args['theme'].'-'.date('YmdHis');
       if ($args['content_format'] == 'text/plain')
       {
         $filename .= '.txt';
@@ -802,10 +818,12 @@ function pwg_send_mail($result, $to, $subject, $content, $headers)
     }
     return $result;
 }
-add_event_handler('send_mail', 'pwg_send_mail_test', EVENT_HANDLER_PRIORITY_NEUTRAL+10, 6);*/
+if ($conf['debug_mail'])
+  add_event_handler('send_mail', 'pwg_send_mail_test', EVENT_HANDLER_PRIORITY_NEUTRAL+10, 6);
 
 
 add_event_handler('send_mail', 'pwg_send_mail', EVENT_HANDLER_PRIORITY_NEUTRAL, 5);
+add_event_handler('send_mail_content', 'move_ccs_rules_to_body');
 trigger_action('functions_mail_included');
 
 ?>
