@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -71,40 +71,78 @@ function custom_notification_query($action, $type, $start, $end)
       $query = '
   FROM '.COMMENTS_TABLE.' AS c
      , '.IMAGE_CATEGORY_TABLE.' AS ic
-  WHERE c.image_id = ic.image_id
-    AND c.validation_date > \''.$start.'\'
-    AND c.validation_date <= \''.$end.'\'
-      '.get_std_sql_where_restrict_filter('AND').'
+  WHERE c.image_id = ic.image_id';
+      if (!empty($start))
+      {
+	$query .= '
+    AND c.validation_date > \''.$start.'\'';
+      }
+      if (!empty($end))
+      {
+	$query .= '      
+    AND c.validation_date <= \''.$end.'\'';
+      }
+      $query .= get_std_sql_where_restrict_filter('AND').'
 ;';
       break;
     case 'unvalidated_comments':
       $query = '
   FROM '.COMMENTS_TABLE.'
-  WHERE date> \''.$start.'\' AND date <= \''.$end.'\'
-    AND validated = \'false\'
+  WHERE 1=1';
+      if (!empty($start))
+      {
+	$query .= ' AND date> \''.$start.'\'';
+      }
+      if (!empty($end))
+      {      
+	$query .= ' AND date <= \''.$end.'\'';
+      }
+      $query .= ' AND validated = \'false\'
 ;';
       break;
     case 'new_elements':
       $query = '
   FROM '.IMAGES_TABLE.' INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON image_id = id
-  WHERE date_available > \''.$start.'\'
-    AND date_available <= \''.$end.'\'
-      '.get_std_sql_where_restrict_filter('AND', 'id').'
+  WHERE 1=1';
+      if (!empty($start))
+      {
+	$query .= ' AND date_available > \''.$start.'\'';
+      }
+      if (!empty($end))
+      {
+	$query .= ' AND date_available <= \''.$end.'\'';
+      }
+      $query .= get_std_sql_where_restrict_filter('AND', 'id').'
 ;';
       break;
     case 'updated_categories':
       $query = '
   FROM '.IMAGES_TABLE.' INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON image_id = id
-  WHERE date_available > \''.$start.'\'
-    AND date_available <= \''.$end.'\'
-      '.get_std_sql_where_restrict_filter('AND', 'id').'
+  WHERE 1=1';
+      if (!empty($start))
+      {
+	$query .= ' AND date_available > \''.$start.'\'';
+      }
+      if (!empty($end))
+      {
+	$query .= ' AND date_available <= \''.$end.'\'';
+      }
+      $query .= get_std_sql_where_restrict_filter('AND', 'id').'
 ;';
       break;
     case 'new_users':
       $query = '
   FROM '.USER_INFOS_TABLE.'
-  WHERE registration_date > \''.$start.'\'
-    AND registration_date <= \''.$end.'\'
+  WHERE 1=1';
+      if (!empty($start))
+      {
+	$query .= ' AND registration_date > \''.$start.'\'';
+      }
+      if (!empty($end))
+      {
+	$query .= ' AND registration_date <= \''.$end.'\'';
+      }
+      $query .= '
 ;';
       break;
     case 'waiting_elements':
@@ -145,7 +183,7 @@ function custom_notification_query($action, $type, $start, $end)
     }
     $query = 'SELECT count(distinct '.$field_id.') as CountId
 '.$query;
-    list($count) = mysql_fetch_array(pwg_query($query));
+    list($count) = pwg_db_fetch_row(pwg_query($query));
     return $count;
 
     break;
@@ -178,7 +216,7 @@ function custom_notification_query($action, $type, $start, $end)
 
     $infos = array();
 
-    while ($row = mysql_fetch_array($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
       array_push($infos, $row);
     }
@@ -391,7 +429,7 @@ function news($start, $end, $exclude_img_cats=false, $add_url=false)
   if (!$exclude_img_cats)
   {
     add_news_line( $news,
-      nb_new_elements($start, $end), '%d new element', '%d new elements',
+      nb_new_elements($start, $end), '%d new image', '%d new images',
       make_index_url(array('section'=>'recent_pics')), $add_url );
   }
 
@@ -444,11 +482,11 @@ SELECT date_available,
   '.$where_sql.'
   GROUP BY date_available
   ORDER BY date_available DESC
-  LIMIT 0,'.$max_dates.'
+  LIMIT '.$max_dates.'
 ;';
   $result = pwg_query($query);
   $dates = array();
-  while ($row = mysql_fetch_assoc($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     array_push($dates, $row);
   }
@@ -458,17 +496,17 @@ SELECT date_available,
     if ($max_elements>0)
     { // get some thumbnails ...
       $query = '
-SELECT DISTINCT id, path, name, tn_ext, file
+SELECT id, path, name, tn_ext, file
   FROM '.IMAGES_TABLE.' i INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON id=image_id
   '.$where_sql.'
-    AND date_available="'.$dates[$i]['date_available'].'"
+    AND date_available=\''.$dates[$i]['date_available'].'\'
     AND tn_ext IS NOT NULL
-  ORDER BY RAND(NOW())
-  LIMIT 0,'.$max_elements.'
+  ORDER BY '.DB_RANDOM_FUNCTION.'()
+  LIMIT '.$max_elements.'
 ;';
       $dates[$i]['elements'] = array();
       $result = pwg_query($query);
-      while ($row = mysql_fetch_assoc($result))
+      while ($row = pwg_db_fetch_assoc($result))
       {
         array_push($dates[$i]['elements'], $row);
       }
@@ -477,18 +515,18 @@ SELECT DISTINCT id, path, name, tn_ext, file
     if ($max_cats>0)
     {// get some categories ...
       $query = '
-SELECT DISTINCT c.uppercats, COUNT(DISTINCT i.id) img_count
+SELECT c.uppercats, COUNT(DISTINCT i.id) img_count
   FROM '.IMAGES_TABLE.' i INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON i.id=image_id
     INNER JOIN '.CATEGORIES_TABLE.' c ON c.id=category_id
   '.$where_sql.'
-    AND date_available="'.$dates[$i]['date_available'].'"
-  GROUP BY category_id
+    AND date_available=\''.$dates[$i]['date_available'].'\'
+  GROUP BY category_id, c.uppercats
   ORDER BY img_count DESC
-  LIMIT 0,'.$max_cats.'
+  LIMIT '.$max_cats.'
 ;';
       $dates[$i]['categories'] = array();
       $result = pwg_query($query);
-      while ($row = mysql_fetch_assoc($result))
+      while ($row = pwg_db_fetch_assoc($result))
       {
         array_push($dates[$i]['categories'], $row);
       }
@@ -526,12 +564,12 @@ function get_html_description_recent_post_date($date_detail)
 
   $description .=
         '<li>'
-        .l10n_dec('%d new element', '%d new elements', $date_detail['nb_elements'])
+        .l10n_dec('%d new image', '%d new images', $date_detail['nb_elements'])
         .' ('
         .'<a href="'.make_index_url(array('section'=>'recent_pics')).'">'
-          .l10n('recent_pics_cat').'</a>'
+          .l10n('Recent pictures').'</a>'
         .')'
-        .'</li><br/>';
+        .'</li><br>';
 
   foreach($date_detail['elements'] as $element)
   {
@@ -541,9 +579,9 @@ function get_html_description_recent_post_date($date_detail)
                         'image_id' => $element['id'],
                         'image_file' => $element['file'],
                       ))
-                    .'"><img src="'.$tn_src.'"/></a>';
+                    .'"><img src="'.$tn_src.'"></a>';
   }
-  $description .= '...<br/>';
+  $description .= '...<br>';
 
   $description .=
         '<li>'
@@ -558,8 +596,8 @@ function get_html_description_recent_post_date($date_detail)
           '<li>'
           .get_cat_display_name_cache($cat['uppercats'])
           .' ('.
-          l10n_dec('%d new element',
-                   '%d new elements', $cat['img_count']).')'
+          l10n_dec('%d new image',
+                   '%d new images', $cat['img_count']).')'
           .'</li>';
   }
   $description .= '</ul>';
@@ -601,7 +639,7 @@ function get_title_recent_post_date($date_detail)
   $date = $date_detail['date_available'];
   $exploded_date = explode_mysqldt($date);
 
-  $title = l10n_dec('%d new element', '%d new elements', $date_detail['nb_elements']);
+  $title = l10n_dec('%d new image', '%d new images', $date_detail['nb_elements']);
   $title .= ' ('.$lang['month'][(int)$exploded_date['month']].' '.$exploded_date['day'].')';
 
   return $title;
