@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -47,7 +47,7 @@ function validate_mail_address($user_id, $mail_address)
 
   if ( !preg_match( $regex, $mail_address ) )
   {
-    return l10n('reg_err_mail_address');
+    return l10n('mail address must be like xxx@yyy.eee (example : jack@altern.org)');
   }
 
   if (defined("PHPWG_INSTALLED") and !empty($mail_address))
@@ -58,10 +58,35 @@ from '.USERS_TABLE.'
 where upper('.$conf['user_fields']['email'].') = upper(\''.$mail_address.'\')
 '.(is_numeric($user_id) ? 'and '.$conf['user_fields']['id'].' != \''.$user_id.'\'' : '').'
 ;';
-    list($count) = mysql_fetch_array(pwg_query($query));
+    list($count) = pwg_db_fetch_row(pwg_query($query));
     if ($count != 0)
     {
-      return l10n('reg_err_mail_address_dbl');
+      return l10n('a user use already this mail address');
+    }
+  }
+}
+
+// validate_login_case:
+//   o check if login is not used by a other user
+// If the login doesn't correspond, an error message is returned.
+//
+function validate_login_case($login)
+{
+  global $conf;
+  
+  if (defined("PHPWG_INSTALLED"))
+  {
+    $query = "
+SELECT ".$conf['user_fields']['username']."
+FROM ".USERS_TABLE."
+WHERE LOWER(".stripslashes($conf['user_fields']['username']).") = '".strtolower($login)."'
+;";
+
+    $count = pwg_db_num_rows(pwg_query($query));
+
+    if ($count > 0)
+    {
+      return l10n('this login is already used');
     }
   }
 }
@@ -73,19 +98,19 @@ function register_user($login, $password, $mail_address,
 
   if ($login == '')
   {
-    array_push($errors, l10n('reg_err_login1'));
+    array_push($errors, l10n('Please, enter a login'));
   }
   if (preg_match('/^.* $/', $login))
   {
-    array_push($errors, l10n('reg_err_login2'));
+    array_push($errors, l10n('login mustn\'t end with a space character'));
   }
   if (preg_match('/^ .*$/', $login))
   {
-    array_push($errors, l10n('reg_err_login3'));
+    array_push($errors, l10n('login mustn\'t start with a space character'));
   }
   if (get_userid($login))
   {
-    array_push($errors, l10n('reg_err_login5'));
+    array_push($errors, l10n('this login is already used'));
   }
   $mail_error = validate_mail_address(null, $mail_address);
   if ('' != $mail_error)
@@ -93,6 +118,15 @@ function register_user($login, $password, $mail_address,
     array_push($errors, $mail_error);
   }
 
+  if ($conf['insensitive_case_logon'] == true)
+  {
+    $login_error = validate_login_case($login);
+    if ($login_error != '')
+    {
+      array_push($errors, $login_error);
+    }
+  }
+
   $errors = trigger_event('register_user_check',
               $errors,
               array(
@@ -110,12 +144,12 @@ function register_user($login, $password, $mail_address,
 SELECT MAX('.$conf['user_fields']['id'].') + 1
   FROM '.USERS_TABLE.'
 ;';
-    list($next_id) = mysql_fetch_array(pwg_query($query));
+    list($next_id) = pwg_db_fetch_row(pwg_query($query));
 
     $insert =
       array(
         $conf['user_fields']['id'] => $next_id,
-        $conf['user_fields']['username'] => mysql_real_escape_string($login),
+        $conf['user_fields']['username'] => pwg_db_real_escape_string($login),
         $conf['user_fields']['password'] => $conf['pass_convert']($password),
         $conf['user_fields']['email'] => $mail_address
         );
@@ -134,7 +168,7 @@ SELECT id
       $result = pwg_query($query);
 
       $inserts = array();
-      while ($row = mysql_fetch_array($result))
+      while ($row = pwg_db_fetch_assoc($result))
       {
         array_push
         (
@@ -170,7 +204,7 @@ SELECT id
 
       $keyargs_content = array
       (
-        get_l10n_args('User: %s', $login),
+        get_l10n_args('User: %s', stripslashes($login)),
         get_l10n_args('Email: %s', $_POST['mail_address']),
         get_l10n_args('', ''),
         get_l10n_args('Admin: %s', $admin_url)
@@ -178,7 +212,7 @@ SELECT id
 
       pwg_mail_notification_admins
       (
-        get_l10n_args('Registration of %s', $login),
+        get_l10n_args('Registration of %s', stripslashes($login)),
         $keyargs_content
       );
     }
@@ -211,7 +245,11 @@ function build_user( $user_id, $use_cache )
   // calculation of the number of picture to display per page
   $user['nb_image_page'] = $user['nb_image_line'] * $user['nb_line_page'];
 
-  list($user['template'], $user['theme']) = explode('/', $user['template']);
+  // Check user theme
+  if (!isset($user['theme_name']))
+  {
+    $user['theme'] = get_default_theme();
+  }
 
   return $user;
 }
@@ -229,6 +267,7 @@ function getuserdata($user_id, $use_cache)
 
   $userdata = array();
 
+  // retrieve basic user data
   $query = '
 SELECT ';
   $is_first = true;
@@ -249,27 +288,46 @@ SELECT ';
   FROM '.USERS_TABLE.'
   WHERE '.$conf['user_fields']['id'].' = \''.$user_id.'\'';
 
-  $row = mysql_fetch_array(pwg_query($query));
+  $row = pwg_db_fetch_assoc(pwg_query($query));
 
-  while (true)
+  // retrieve user info
+  $query = '
+SELECT
+    ui.*,
+    uc.*,
+    t.name AS theme_name
+  FROM '.USER_INFOS_TABLE.' AS ui
+    LEFT JOIN '.USER_CACHE_TABLE.' AS uc ON ui.user_id = uc.user_id
+    LEFT JOIN '.THEMES_TABLE.' AS t ON t.id = ui.theme
+  WHERE ui.user_id = '.$user_id.'
+;';
+
+  $result = pwg_query($query);
+  $user_infos_row = pwg_db_fetch_assoc($result);
+
+  // retrieve additional user data ?
+  if ($conf['external_authentification'])
   {
     $query = '
-SELECT ui.*, uc.*
-  FROM '.USER_INFOS_TABLE.' AS ui LEFT JOIN '.USER_CACHE_TABLE.' AS uc
-    ON ui.user_id = uc.user_id
-  WHERE ui.user_id = \''.$user_id.'\'';
-    $result = pwg_query($query);
-    if (mysql_num_rows($result) > 0)
-    {
-      break;
-    }
-    else
+SELECT
+    COUNT(1) AS counter,
+  FROM '.USER_INFOS_TABLE.' AS ui
+    LEFT JOIN '.USER_CACHE_TABLE.' AS uc ON ui.user_id = uc.user_id
+    LEFT JOIN '.THEMES_TABLE.' AS t ON t.id = ui.theme
+  WHERE ui.user_id = '.$user_id.'
+  GROUP BY ui.user_id
+;';
+    if (pwg_db_fetch_row(pwg_query($query))!=1)
     {
       create_user_infos($user_id);
+    
+      $result = pwg_query($user_info_query);
+      $user_infos_row = pwg_db_fetch_assoc($result);      
     }
   }
 
-  $row = array_merge($row, mysql_fetch_array($result));
+  // then merge basic + additional user data
+  $row = array_merge($row, $user_infos_row);
 
   foreach ($row as $key => $value)
   {
@@ -324,7 +382,7 @@ SELECT COUNT(DISTINCT(image_id)) as total
   FROM '.IMAGE_CATEGORY_TABLE.'
   WHERE category_id NOT IN ('.$userdata['forbidden_categories'].')
     AND image_id '.$userdata['image_access_type'].' ('.$userdata['image_access_list'].')';
-      list($userdata['nb_total_images']) = mysql_fetch_array(pwg_query($query));
+      list($userdata['nb_total_images']) = pwg_db_fetch_row(pwg_query($query));
 
 
       // now we update user cache categories
@@ -385,8 +443,8 @@ INSERT INTO '.USER_CACHE_TABLE.'
   VALUES
   ('.$userdata['id'].',\''.boolean_to_string($userdata['need_update']).'\','
   .$userdata['cache_update_time'].',\''
-  .$userdata['forbidden_categories'].'\','.$userdata['nb_total_images'].',"'
-  .$userdata['image_access_type'].'","'.$userdata['image_access_list'].'")';
+  .$userdata['forbidden_categories'].'\','.$userdata['nb_total_images'].',\''
+  .$userdata['image_access_type'].'\',\''.$userdata['image_access_list'].'\')';
       pwg_query($query);
     }
   }
@@ -428,7 +486,7 @@ SELECT DISTINCT f.image_id
 ;';
   $result = pwg_query($query);
   $authorizeds = array();
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     array_push($authorizeds, $row['image_id']);
   }
@@ -440,7 +498,7 @@ SELECT image_id
 ;';
   $result = pwg_query($query);
   $favorites = array();
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     array_push($favorites, $row['image_id']);
   }
@@ -481,7 +539,7 @@ SELECT id
   WHERE status = \'private\'
 ;';
   $result = pwg_query($query);
-  while ($row = mysql_fetch_array($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     array_push($private_array, $row['id']);
   }
@@ -523,7 +581,7 @@ SELECT id
   WHERE visible = \'false\'
 ;';
     $result = pwg_query($query);
-    while ($row = mysql_fetch_array($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
       array_push($forbidden_array, $row['id']);
     }
@@ -632,7 +690,7 @@ FROM '.CATEGORIES_TABLE.' as c
 
   if ( isset($filter_days) )
   {
-    $query .= ' AND i.date_available > SUBDATE(CURRENT_DATE,INTERVAL '.$filter_days.' DAY)';
+    $query .= ' AND i.date_available > '.pwg_db_get_recent_period_expression($filter_days);
   }
 
   if ( !empty($userdata['forbidden_categories']) )
@@ -642,12 +700,12 @@ FROM '.CATEGORIES_TABLE.' as c
   }
 
   $query.= '
-  GROUP BY c.id';
+  GROUP BY c.id, c.global_rank';
 
   $result = pwg_query($query);
 
   $cats = array();
-  while ($row = mysql_fetch_assoc($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $row['user_id'] = $userdata['id'];
     $row['count_categories'] = 0;
@@ -692,7 +750,7 @@ function get_userid($username)
 {
   global $conf;
 
-  $username = mysql_real_escape_string($username);
+  $username = pwg_db_real_escape_string($username);
 
   $query = '
 SELECT '.$conf['user_fields']['id'].'
@@ -701,13 +759,13 @@ SELECT '.$conf['user_fields']['id'].'
 ;';
   $result = pwg_query($query);
 
-  if (mysql_num_rows($result) == 0)
+  if (pwg_db_num_rows($result) == 0)
   {
     return false;
   }
   else
   {
-    list($user_id) = mysql_fetch_row($result);
+    list($user_id) = pwg_db_fetch_row($result);
     return $user_id;
   }
 }
@@ -727,7 +785,7 @@ SELECT COUNT(*)
   FROM '.USER_FEED_TABLE.'
   WHERE id = \''.$key.'\'
 ;';
-    list($count) = mysql_fetch_row(pwg_query($query));
+    list($count) = pwg_db_fetch_row(pwg_query($query));
     if (0 == $count)
     {
       return $key;
@@ -750,13 +808,54 @@ function get_default_user_info($convert_str = true)
             ' WHERE user_id = '.$conf['default_user_id'].';';
 
     $result = pwg_query($query);
-    $cache['default_user'] = mysql_fetch_assoc($result);
+    $cache['default_user'] = pwg_db_fetch_assoc($result);
 
     if ($cache['default_user'] !== false)
     {
       unset($cache['default_user']['user_id']);
       unset($cache['default_user']['status']);
       unset($cache['default_user']['registration_date']);
+
+      // theme and language fields may be null in the database (see
+      // bug:1683) This is absolutely not nice to have this code in this
+      // very place, but it avoids a complexe upgrade with an "automatic
+      // fix" in the database => this code should be removed after branch
+      // 2.1 if a migration tasks performs the job the same way
+      if (empty($cache['default_user']['theme']))
+      {
+        mass_updates(
+          USER_INFOS_TABLE,
+          array(
+            'primary' => array('user_id'),
+            'update'  => array('theme')
+            ),
+          array(
+            array(
+              'user_id' => $conf['default_user_id'],
+              'theme' => PHPWG_DEFAULT_TEMPLATE
+              )
+            )
+          );
+        $cache['default_user']['theme'] = PHPWG_DEFAULT_TEMPLATE;
+      }
+      
+      if (empty($cache['default_user']['language']))
+      {
+        mass_updates(
+          USER_INFOS_TABLE,
+          array(
+            'primary' => array('user_id'),
+            'update'  => array('language')
+            ),
+          array(
+            array(
+              'user_id' => $conf['default_user_id'],
+              'language' => PHPWG_DEFAULT_LANGUAGE
+              )
+            )
+          );
+        $cache['default_user']['language'] = PHPWG_DEFAULT_LANGUAGE;
+      }
     }
   }
 
@@ -793,7 +892,7 @@ function get_default_user_info($convert_str = true)
 function get_default_user_value($value_name, $sos_value)
 {
   $default_user = get_default_user_info(true);
-  if ($default_user === false or !isset($default_user[$value_name]))
+  if ($default_user === false or empty($default_user[$value_name]))
   {
     return $sos_value;
   }
@@ -807,9 +906,23 @@ function get_default_user_value($value_name, $sos_value)
  * Returns the default template value
  *
  */
-function get_default_template()
+function get_default_theme()
 {
-  return get_default_user_value('template', PHPWG_DEFAULT_TEMPLATE);
+  $theme = get_default_user_value('theme', PHPWG_DEFAULT_TEMPLATE);
+  if (check_theme_installed($theme))
+  {
+    return $theme;
+  }
+  
+  // let's find the first available theme
+  $active_themes = get_pwg_themes();
+  foreach (array_keys(get_pwg_themes()) as $theme_id)
+  {
+    if (check_theme_installed($theme_id))
+    {
+      return $theme_id;
+    }
+  }
 }
 
 /*
@@ -865,7 +978,7 @@ function create_user_infos($arg_id, $override_values = null)
   if (!empty($user_ids))
   {
     $inserts = array();
-    list($dbnow) = mysql_fetch_row(pwg_query('SELECT NOW();'));
+    list($dbnow) = pwg_db_fetch_row(pwg_query('SELECT NOW();'));
 
     $default_user = get_default_user_info(false);
     if ($default_user === false)
@@ -930,11 +1043,11 @@ SELECT '.$conf['user_fields']['username'].' AS username
 FROM '.USERS_TABLE.'
 WHERE '.$conf['user_fields']['id'].' = '.$user_id;
   $result = pwg_query($query);
-  if (mysql_num_rows($result) > 0)
+  if (pwg_db_num_rows($result) > 0)
   {
-    $row = mysql_fetch_assoc($result);
-    $username = $row['username'];
-    $data = $time.$row['username'].$row['password'];
+    $row = pwg_db_fetch_assoc($result);
+    $username = stripslashes($row['username']);
+    $data = $time.stripslashes($row['username']).$row['password'];
     $key = base64_encode(
       pack('H*', sha1($data))
       .hash_hmac('md5', $data, $conf['secret_key'],true)
@@ -1018,7 +1131,7 @@ function auto_login() {
       if ($key!==false and $key===$cookie[2])
       {
         log_user($cookie[0], true);
-        trigger_action('login_success', $username);
+        trigger_action('login_success', stripslashes($username));
         return true;
       }
     }
@@ -1039,16 +1152,16 @@ function try_log_user($username, $password, $remember_me)
 SELECT '.$conf['user_fields']['id'].' AS id,
        '.$conf['user_fields']['password'].' AS password
   FROM '.USERS_TABLE.'
-  WHERE '.$conf['user_fields']['username'].' = \''.$username.'\'
+  WHERE '.$conf['user_fields']['username'].' = \''.pwg_db_real_escape_string($username).'\'
 ;';
-  $row = mysql_fetch_assoc(pwg_query($query));
+  $row = pwg_db_fetch_assoc(pwg_query($query));
   if ($row['password'] == $conf['pass_convert']($password))
   {
     log_user($row['id'], $remember_me);
-    trigger_action('login_success', $username);
+    trigger_action('login_success', stripslashes($username));
     return true;
   }
-  trigger_action('login_failure', $username);
+  trigger_action('login_failure', stripslashes($username));
   return false;
 }
 
@@ -1196,6 +1309,15 @@ function check_status($access_type, $user_status = '')
   return is_autorize_status(ACCESS_ADMINISTRATOR, $user_status);
 }
 
+/*
+ * Return if user is, at least, a webmaster
+ * @return bool
+*/
+ function is_webmaster($user_status = '')
+{
+  return is_autorize_status(ACCESS_WEBMASTER, $user_status);
+}
+
 /*
  * Return if current user is an adviser
  * @return bool
@@ -1207,6 +1329,47 @@ function is_adviser()
   return ($user['adviser'] == 'true');
 }
 
+/*
+ * Return if current user can edit/delete/validate a comment
+ * @param action edit/delete/validate
+ * @return bool
+ */
+function can_manage_comment($action, $comment_author_id)
+{
+  global $user, $conf;
+  
+  if (is_a_guest())
+  {
+    return false;
+  }
+  
+  if (!in_array($action, array('delete','edit', 'validate')))
+  {
+    return false;
+  }
+
+  if (is_admin())
+  {
+    return true;
+  }
+
+  if ('edit' == $action and $conf['user_can_edit_comment'])
+  {
+    if ($comment_author_id == $user['id']) {
+      return true;
+    }
+  }
+
+  if ('delete' == $action and $conf['user_can_delete_comment'])
+  {
+    if ($comment_author_id == $user['id']) {
+      return true;
+    }
+  }
+
+  return false;
+}
+
 /*
  * Return mail address as display text
  * @return string
