@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -108,6 +108,7 @@ if (script_basename() == 'picture') // basename without file extention
     }
     else
     {
+      $page['image_id'] = 0; // more work in picture.php
       if ( !empty($matches[2]) )
       {
         $page['image_file'] = $matches[2];
@@ -121,6 +122,7 @@ if (script_basename() == 'picture') // basename without file extention
 }
 
 $page = array_merge( $page, parse_section_url( $tokens, $next_token) );
+
 if ( !isset($page['section']) )
 {
   $page['section'] = 'categories';
@@ -155,10 +157,7 @@ if ( !isset($page['section']) )
   }
 }
 
-
 $page = array_merge( $page, parse_well_known_params_url( $tokens, $next_token) );
-
-
 if ( script_basename()=='picture' and 'categories'==$page['section'] and
       !isset($page['category']) and !isset($page['chronology_field']) )
 { //access a picture only by id, file or id-file without given section
@@ -220,8 +219,6 @@ $forbidden = get_sql_condition_FandF(
 // +-----------------------------------------------------------------------+
 if ('categories' == $page['section'])
 {
-  $page['title'] = '<a href="'.get_absolute_root_url().$conf['home_page'].'">'.l10n('home').'</a>';
-
   if (isset($page['category']))
   {
     $page = array_merge(
@@ -233,11 +230,12 @@ if ('categories' == $page['section'])
               $page['category']['comment'],
               'main_page_category_description'
             ),
-        'title'             =>
-          $page['title'].$conf['level_separator'].get_cat_display_name($page['category']['upper_names'], '', false),
+        'title'             => get_cat_display_name($page['category']['upper_names'], '', false),
         )
       );
   }
+  else
+    $page['title'] = ''; // will be set later
 
   if
     (
@@ -291,7 +289,7 @@ SELECT id
 
     // Main query
     $query = '
-SELECT DISTINCT(image_id)
+SELECT DISTINCT(image_id)'.get_extra_fields($conf['order_by']).'
   FROM '.IMAGE_CATEGORY_TABLE.'
     INNER JOIN '.IMAGES_TABLE.' ON id = image_id
   WHERE
@@ -325,7 +323,7 @@ else
     if (!empty($items) )
     {
       $query = '
-SELECT DISTINCT image_id
+SELECT DISTINCT image_id'.get_extra_fields($conf['order_by']).'
   FROM '.IMAGE_CATEGORY_TABLE.' INNER JOIN '.IMAGES_TABLE.' ON image_id=id
   WHERE image_id IN ('.implode(',', $items).')
     '.$forbidden.
@@ -360,7 +358,7 @@ SELECT DISTINCT image_id
       array(
         'items' => $search_result['items'],
         'title' => '<a href="'.duplicate_index_url(array('start'=>0)).'">'
-                  .l10n('search_result').'</a>',
+                  .l10n('Search results').'</a>',
         )
       );
   }
@@ -371,7 +369,25 @@ SELECT DISTINCT image_id
   {
     check_user_favorites();
 
-    $query = '
+    $page = array_merge(
+      $page,
+      array(
+        'title' => l10n('Favorites')
+      )
+    );
+
+    if (!empty($_GET['action']) && ($_GET['action'] == 'remove_all_from_favorites'))
+    {
+      $query = '
+DELETE FROM '.FAVORITES_TABLE.'
+  WHERE user_id = '.$user['id'].'
+;';
+      pwg_query($query);
+      redirect(make_index_url( array('section'=>'favorites') ));
+    }
+    else
+    {
+      $query = '
 SELECT image_id
   FROM '.FAVORITES_TABLE.'
     INNER JOIN '.IMAGES_TABLE.' ON image_id = id
@@ -386,14 +402,28 @@ SELECT image_id
   ).'
   '.$conf['order_by'].'
 ;';
-
-    $page = array_merge(
-      $page,
-      array(
-        'title' => l10n('favorites'),
-        'items' => array_from_query($query, 'image_id'),
-        )
+      $page = array_merge(
+	$page,
+	array(
+	  'items' => array_from_query($query, 'image_id'),
+         )
       );
+
+      if (count($page['items'])>0)
+      {
+	$template->assign(
+	  'favorite',
+	  array(
+	    'FAVORITE_IMG'  =>
+	    get_root_url().get_themeconf('icon_dir').'/del_all_favorites.png',
+	    'U_FAVORITE'    => add_url_params(
+	      make_index_url( array('section'=>'favorites') ),
+	      array('action'=>'remove_all_from_favorites')
+	       ),
+	     )
+           );
+      }
+    }
   }
 // +-----------------------------------------------------------------------+
 // |                       recent pictures section                         |
@@ -410,12 +440,11 @@ SELECT image_id
     }
 
     $query = '
-SELECT DISTINCT(id)
+SELECT DISTINCT(id)'.get_extra_fields($conf['order_by']).'
   FROM '.IMAGES_TABLE.'
     INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON id = ic.image_id
   WHERE
-    date_available >= SUBDATE(
-      CURRENT_DATE,INTERVAL '.$user['recent_period'].' DAY)
+    date_available >= '.pwg_db_get_recent_period_expression($user['recent_period']).'
     '.$forbidden.'
   '.$conf['order_by'].'
 ;';
@@ -424,7 +453,7 @@ SELECT DISTINCT(id)
       $page,
       array(
         'title' => '<a href="'.duplicate_index_url(array('start'=>0)).'">'
-                  .l10n('recent_pics_cat').'</a>',
+                  .l10n('Recent pictures').'</a>',
         'items' => array_from_query($query, 'id'),
         )
       );
@@ -437,7 +466,7 @@ SELECT DISTINCT(id)
     $page = array_merge(
       $page,
       array(
-        'title' => l10n('recent_cats_cat'),
+        'title' => l10n('Recent categories'),
         )
       );
   }
@@ -449,20 +478,20 @@ SELECT DISTINCT(id)
     $page['super_order_by'] = true;
     $conf['order_by'] = ' ORDER BY hit DESC, file ASC';
     $query = '
-SELECT DISTINCT(id)
+SELECT DISTINCT(id), hit, file
   FROM '.IMAGES_TABLE.'
     INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON id = ic.image_id
   WHERE hit > 0
     '.$forbidden.'
     '.$conf['order_by'].'
-  LIMIT 0, '.$conf['top_number'].'
+  LIMIT '.$conf['top_number'].'
 ;';
 
     $page = array_merge(
       $page,
       array(
         'title' => '<a href="'.duplicate_index_url(array('start'=>0)).'">'
-                  .$conf['top_number'].' '.l10n('most_visited_cat').'</a>',
+                  .$conf['top_number'].' '.l10n('Most visited').'</a>',
         'items' => array_from_query($query, 'id'),
         )
       );
@@ -476,19 +505,19 @@ SELECT DISTINCT(id)
     $conf['order_by'] = ' ORDER BY average_rate DESC, id ASC';
 
     $query ='
-SELECT DISTINCT(id)
+SELECT DISTINCT(id), average_rate
   FROM '.IMAGES_TABLE.'
     INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON id = ic.image_id
   WHERE average_rate IS NOT NULL
     '.$forbidden.'
     '.$conf['order_by'].'
-  LIMIT 0, '.$conf['top_number'].'
+  LIMIT '.$conf['top_number'].'
 ;';
     $page = array_merge(
       $page,
       array(
         'title' => '<a href="'.duplicate_index_url(array('start'=>0)).'">'
-                  .$conf['top_number'].' '.l10n('best_rated_cat').'</a>',
+                  .$conf['top_number'].' '.l10n('Best rated').'</a>',
         'items' => array_from_query($query, 'id'),
         )
       );
@@ -499,7 +528,7 @@ SELECT DISTINCT(id)
   else if ($page['section'] == 'list')
   {
     $query ='
-SELECT DISTINCT(id)
+SELECT DISTINCT(id)'.get_extra_fields($conf['order_by']).'
   FROM '.IMAGES_TABLE.'
     INNER JOIN '.IMAGE_CATEGORY_TABLE.' AS ic ON id = ic.image_id
   WHERE image_id IN ('.implode(',', $page['list']).')
@@ -511,7 +540,7 @@ SELECT DISTINCT(id)
       $page,
       array(
         'title' => '<a href="'.duplicate_index_url(array('start'=>0)).'">'
-                    .l10n('random_cat').'</a>',
+                    .l10n('Random pictures').'</a>',
         'items' => array_from_query($query, 'id'),
         )
       );
@@ -528,10 +557,14 @@ if (isset($page['chronology_field']))
   initialize_calendar();
 }
 
-if (script_basename() == 'picture'
-    and !isset($page['image_id']) )
+// title update
+if (isset($page['title']))
 {
-  $page['image_id'] = 0; // more work in picture.php
+  if (!empty($page['title']))
+	{
+	  $page['title'] = $conf['level_separator'].$page['title'];
+	}
+  $page['title'] = '<a href="'.get_gallery_home_url().'">'.l10n('Home').'</a>'.$page['title'];
 }
 
 // add meta robots noindex, nofollow to avoid unnecesary robot crawls
