@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -24,15 +24,6 @@
 
 require_once(PHPWG_ROOT_PATH.'include/smarty/libs/Smarty.class.php');
 
-// migrate lang:XXX
-//    sed "s/{lang:\([^}]\+\)}/{\'\1\'|@translate}/g" my_template.tpl
-// migrate change root level vars {XXX}
-//    sed "s/{pwg_root}/{ROOT_URL}/g" my_template.tpl
-// migrate change root level vars {XXX}
-//    sed "s/{\([a-zA-Z_]\+\)}/{$\1}/g" my_template.tpl
-// migrate all
-//    cat my_template.tpl | sed "s/{lang:\([^}]\+\)}/{\'\1\'|@translate}/g" | sed "s/{pwg_root}/{ROOT_URL}/g" | sed "s/{\([a-zA-Z_]\+\)}/{$\1}/g"
-
 
 class Template {
 
@@ -48,18 +39,39 @@ class Template {
 
   // Templates prefilter from external sources (plugins)
   var $external_filters = array();
-  
+
   // used by html_head smarty block to add content before </head>
   var $html_head_elements = array();
 
-  function Template($root = ".", $theme= "")
+  function Template($root = ".", $theme= "", $path = "template")
   {
     global $conf, $lang_info;
 
     $this->smarty = new Smarty;
     $this->smarty->debugging = $conf['debug_template'];
-    $this->smarty->compile_check=$conf['template_compile_check'];
+    $this->smarty->compile_check = $conf['template_compile_check'];
+    $this->smarty->force_compile = $conf['template_force_compile'];
 
+    if (!isset($conf['local_data_dir_checked']))
+    {
+      mkgetdir($conf['local_data_dir'], MKGETDIR_DEFAULT&~MKGETDIR_DIE_ON_ERROR);
+      if (!is_writable($conf['local_data_dir']))
+      {
+        load_language('admin.lang');
+        fatal_error(
+          sprintf(
+            l10n('Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'),
+            basename($conf['local_data_dir'])
+            ),
+          l10n('an error happened'),
+          false // show trace
+          );
+      }
+      if (function_exists('pwg_query')) {
+        conf_update_param('local_data_dir_checked', 'true');
+      }
+    }
+    
     $compile_dir = $conf['local_data_dir'].'/templates_c';
     mkgetdir( $compile_dir );
 
@@ -77,33 +89,71 @@ class Template {
       $this->smarty->register_prefilter( array('Template', 'prefilter_language') );
     }
 
+    $this->smarty->template_dir = array();
     if ( !empty($theme) )
     {
-      include($root.'/theme/'.$theme.'/themeconf.inc.php');
-      $this->smarty->assign('themeconf', $themeconf);
+      $this->set_theme($root, $theme, $path);
+      $this->set_prefilter( 'header', array('Template', 'prefilter_local_css') );
     }
+    else
+      $this->set_template_dir($root);
 
     $this->smarty->assign('lang_info', $lang_info);
 
-    $this->set_template_dir($root);
-
     if (!defined('IN_ADMIN') and isset($conf['extents_for_templates']))
     {
       $tpl_extents = unserialize($conf['extents_for_templates']);
-      $this->set_extents($tpl_extents, './template-extension/', true);
+      $this->set_extents($tpl_extents, './template-extension/', true, $theme);
     }
   }
 
   /**
-   * Sets the template root directory for this Template object.
+   * Load theme's parameters.
+   */
+  function set_theme($root, $theme, $path, $load_css=true, $load_local_head=true)
+  {
+    $this->set_template_dir($root.'/'.$theme.'/'.$path);
+
+    $themeconf = $this->load_themeconf($root.'/'.$theme);
+
+    if (isset($themeconf['parent']) and $themeconf['parent'] != $theme)
+    {
+      $this->set_theme(
+        $root,
+        $themeconf['parent'],
+        $path,
+        isset($themeconf['load_parent_css']) ? $themeconf['load_parent_css'] : $load_css,
+        isset($themeconf['load_parent_local_head']) ? $themeconf['load_parent_local_head'] : $load_local_head
+      );
+    }
+
+    $tpl_var = array(
+      'id' => $theme,
+      'load_css' => $load_css,
+    );
+    if (!empty($themeconf['local_head']) and $load_local_head)
+    {
+      $tpl_var['local_head'] = realpath($root.'/'.$theme.'/'.$themeconf['local_head'] );
+    }
+    $themeconf['id'] = $theme;
+    $this->smarty->append('themes', $tpl_var);
+    $this->smarty->append('themeconf', $themeconf, true);
+  }
+
+  /**
+   * Add template directory for this Template object.
+   * Set compile id if not exists.
    */
   function set_template_dir($dir)
   {
-    $this->smarty->template_dir = $dir;
+    $this->smarty->template_dir[] = $dir;
 
-    $real_dir = realpath($dir);
-    $compile_id = crc32( $real_dir===false ? $dir : $real_dir);
-    $this->smarty->compile_id = base_convert($compile_id, 10, 36 );
+    if (!isset($this->smarty->compile_id))
+    {
+      $real_dir = realpath($dir);
+      $compile_id = crc32( $real_dir===false ? $dir : $real_dir);
+      $this->smarty->compile_id = base_convert($compile_id, 10, 36 );
+    }
   }
 
   /**
@@ -168,7 +218,7 @@ class Template {
   /**
    * Sets template extention filename for handles.
    */
-  function set_extent($filename, $param, $dir='', $overwrite=true)
+  function set_extent($filename, $param, $dir='', $overwrite=true, $theme='N/A')
   {
     return $this->set_extents(array($filename => $param), $dir, $overwrite);
   }
@@ -177,7 +227,7 @@ class Template {
    * Sets template extentions filenames for handles.
    * $filename_array should be an hash of filename => array( handle, param) or filename => handle
    */
-  function set_extents($filename_array, $dir='', $overwrite=true)
+  function set_extents($filename_array, $dir='', $overwrite=true, $theme='N/A')
   {
     if (!is_array($filename_array))
     {
@@ -189,13 +239,13 @@ class Template {
       {
         $handle = $value[0];
         $param = $value[1];
-        $tpl = $value[2];
+        $thm = $value[2];
       }
       elseif (is_string($value))
       {
         $handle = $value;
         $param = 'N/A';
-        $tpl = 'N/A';
+        $thm = 'N/A';
       }
       else
       {
@@ -203,7 +253,7 @@ class Template {
       }
 
       if ((stripos(implode('',array_keys($_GET)), '/'.$param) !== false or $param == 'N/A')
-        and (preg_match('/'.preg_quote($tpl,'/').'$/', $this->get_template_dir()) or $tpl == 'N/A')
+        and ($thm == $theme or $thm == 'N/A')
         and (!isset($this->extents[$handle]) or $overwrite)
         and file_exists($dir . $filename))
       {
@@ -446,7 +496,7 @@ class Template {
     $this->external_filters[$handle][$weight][] = array('outputfilter', $callback);
     ksort($this->external_filters[$handle]);
   }
-  
+
  /**
    * This function actually triggers the filters on the tpl files.
    * Called in the parse method.
@@ -457,9 +507,9 @@ class Template {
     if (isset($this->external_filters[$handle]))
     {
       $compile_id = '';
-      foreach ($this->external_filters[$handle] as $filters) 
+      foreach ($this->external_filters[$handle] as $filters)
       {
-        foreach ($filters as $filter) 
+        foreach ($filters as $filter)
         {
           list($type, $callback) = $filter;
           $compile_id .= $type.( is_array($callback) ? implode('', $callback) : $callback );
@@ -474,9 +524,9 @@ class Template {
   {
     if (isset($this->external_filters[$handle]))
     {
-      foreach ($this->external_filters[$handle] as $filters) 
+      foreach ($this->external_filters[$handle] as $filters)
       {
-        foreach ($filters as $filter) 
+        foreach ($filters as $filter)
         {
           list($type, $callback) = $filter;
           call_user_func(array($this->smarty, 'unregister_'.$type), $callback);
@@ -529,6 +579,45 @@ class Template {
 
     return $source;
   }
+
+  static function prefilter_local_css($source, &$smarty)
+  {
+    $css = array();
+
+    foreach ($smarty->get_template_vars('themes') as $theme)
+    {
+      if (file_exists(PHPWG_ROOT_PATH.'local/css/'.$theme['id'].'-rules.css'))
+      {
+        array_push($css, '<link rel="stylesheet" type="text/css" href="{$ROOT_URL}local/css/'.$theme['id'].'-rules.css">');
+      }
+    }
+    if (file_exists(PHPWG_ROOT_PATH.'local/css/rules.css'))
+    {
+      array_push($css, '<link rel="stylesheet" type="text/css" href="{$ROOT_URL}local/css/rules.css">');
+    }
+
+    if (!empty($css))
+    {
+      $source = str_replace("\n</head>", "\n".implode( "\n", $css )."\n</head>", $source);
+    }
+
+    return $source;
+  }
+
+  function load_themeconf($dir)
+  {
+    global $themeconfs, $conf;
+
+    $dir = realpath($dir);
+    if (!isset($themeconfs[$dir]))
+    {
+      $themeconf = array();
+      include($dir.'/themeconf.inc.php');
+      // Put themeconf in cache
+      $themeconfs[$dir] = $themeconf;
+    }
+    return $themeconfs[$dir];
+  }
 }
 
 
