@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -203,7 +203,7 @@ class PwgResponseEncoder
       $changed = 0;
       $changed += PwgResponseEncoder::_removeNamedArray($value);
       $changed += PwgResponseEncoder::_removeNamedStruct($value);
-  //    print_r('walk '.$key."<br/>\n");
+  //    print_r('walk '.$key."<br>\n");
     }
     while ($changed);
   }
@@ -218,7 +218,7 @@ class PwgResponseEncoder
     print_r( '_mergeAttributesAndContent is_struct='.PwgResponseEncoder::is_struct($value)
       .' count='.count($value)
       .' first_key='.$first_key
-      ."<br/>\n"
+      ."<br>\n"
       );*/
     $ret = 0;
     if (PwgResponseEncoder::is_struct($value))
