@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -121,15 +121,15 @@ function ws_std_image_sql_order( $params, $tbl_name='' )
       case 'date_posted':
         $matches[1][$i] = 'date_available'; break;
       case 'rand': case 'random':
-        $matches[1][$i] = 'RAND()'; break;
+        $matches[1][$i] = DB_RANDOM_FUNCTION.'()'; break;
     }
     $sortable_fields = array('id', 'file', 'name', 'hit', 'average_rate',
-      'date_creation', 'date_available', 'RAND()' );
+      'date_creation', 'date_available', DB_RANDOM_FUNCTION.'()' );
     if ( in_array($matches[1][$i], $sortable_fields) )
     {
       if (!empty($ret))
         $ret .= ', ';
-      if ($matches[1][$i] != 'RAND()' )
+      if ($matches[1][$i] != DB_RANDOM_FUNCTION.'()' )
       {
         $ret .= $tbl_name;
       }
@@ -230,7 +230,7 @@ function ws_categories_getImages($params, &$service)
       continue;
     if ($params['recursive'])
     {
-      $where_clauses[] = 'uppercats REGEXP \'(^|,)'.$cat_id.'(,|$)\'';
+      $where_clauses[] = 'uppercats '.DB_REGEX_OPERATOR.' \'(^|,)'.$cat_id.'(,|$)\'';
     }
     else
     {
@@ -256,7 +256,7 @@ SELECT id, name, permalink, image_order
     AND ', $where_clauses);
   $result = pwg_query($query);
   $cats = array();
-  while ($row = mysql_fetch_assoc($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $row['id'] = (int)$row['id'];
     $cats[ $row['id'] ] = $row;
@@ -292,10 +292,10 @@ SELECT i.*, GROUP_CONCAT(category_id) cat_ids
     AND ', $where_clauses).'
 GROUP BY i.id
 '.$order_by.'
-LIMIT '.(int)($params['per_page']*$params['page']).','.(int)$params['per_page'];
+LIMIT '.(int)$params['per_page'].' OFFSET '.(int)($params['per_page']*$params['page']);
 
     $result = pwg_query($query);
-    while ($row = mysql_fetch_assoc($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
       $image = array();
       foreach ( array('id', 'width', 'height', 'hit') as $k )
@@ -379,7 +379,7 @@ function ws_categories_getList($params, &$service)
   }
   else if ($params['cat_id']>0)
   {
-    $where[] = 'uppercats REGEXP \'(^|,)'.
+    $where[] = 'uppercats '.DB_REGEX_OPERATOR.' \'(^|,)'.
       (int)($params['cat_id'])
       .'(,|$)\'';
   }
@@ -415,7 +415,7 @@ SELECT id, name, permalink, uppercats, global_rank,
   $result = pwg_query($query);
 
   $cats = array();
-  while ($row = mysql_fetch_assoc($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $row['url'] = make_index_url(
         array(
@@ -489,7 +489,7 @@ SELECT
   $result = pwg_query($query);
   $cats = array();
 
-  while ($row = mysql_fetch_assoc($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     $id = $row['id'];
     $row['nb_images'] = isset($nb_images_of[$id]) ? $nb_images_of[$id] : 0;
@@ -542,14 +542,14 @@ SELECT DISTINCT image_id
       ),
       ' AND'
     );
-  if ( !mysql_num_rows( pwg_query( $query ) ) )
+  if ( !pwg_db_num_rows( pwg_query( $query ) ) )
   {
     return new PwgError(WS_ERR_INVALID_PARAM, "Invalid image_id");
   }
 
   $comm = array(
-    'author' => trim( stripslashes($params['author']) ),
-    'content' => trim( stripslashes($params['content']) ),
+    'author' => trim( $params['author'] ),
+    'content' => trim( $params['content'] ),
     'image_id' => $params['image_id'],
    );
 
@@ -562,7 +562,7 @@ SELECT DISTINCT image_id
   switch ($comment_action)
   {
     case 'reject':
-      array_push($infos, l10n('comment_not_added') );
+      array_push($infos, l10n('Your comment has NOT been registered because it did not pass the validation rules') );
       return new PwgError(403, implode("\n", $infos) );
     case 'validate':
     case 'moderate':
@@ -602,7 +602,7 @@ SELECT * FROM '.IMAGES_TABLE.'
     ).'
 LIMIT 1';
 
-  $image_row = mysql_fetch_assoc(pwg_query($query));
+  $image_row = pwg_db_fetch_assoc(pwg_query($query));
   if ($image_row==null)
   {
     return new PwgError(404, "image_id not found");
@@ -623,7 +623,7 @@ SELECT id, name, permalink, uppercats, global_rank, commentable
   $result = pwg_query($query);
   $is_commentable = false;
   $related_categories = array();
-  while ($row = mysql_fetch_assoc($result))
+  while ($row = pwg_db_fetch_assoc($result))
   {
     if ($row['commentable']=='true')
     {
@@ -676,11 +676,10 @@ SELECT id, name, permalink, uppercats, global_rank, commentable
   $query = '
 SELECT COUNT(rate) AS count
      , ROUND(AVG(rate),2) AS average
-     , ROUND(STD(rate),2) AS stdev
   FROM '.RATE_TABLE.'
   WHERE element_id = '.$image_row['id'].'
 ;';
-  $rating = mysql_fetch_assoc(pwg_query($query));
+  $rating = pwg_db_fetch_assoc(pwg_query($query));
   $rating['count'] = (int)$rating['count'];
 
   //---------------------------------------------------------- related comments
@@ -707,11 +706,11 @@ SELECT id, date, author, content
   FROM '.COMMENTS_TABLE.'
   WHERE '.$where_comments.'
   ORDER BY date
-  LIMIT '.(int)($params['comments_per_page']*$params['comments_page']).
-    ','.(int)$params['comments_per_page'];
+  LIMIT '.(int)$params['comments_per_page'].
+    ' OFFSET '.(int)($params['comments_per_page']*$params['comments_page']);
 
     $result = pwg_query($query);
-    while ($row = mysql_fetch_assoc($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
       $row['id']=(int)$row['id'];
       array_push($related_comments, $row);
@@ -725,7 +724,7 @@ SELECT id, date, author, content
       )
       )
   {
-    $comment_post_data['author'] = $user['username'];
+    $comment_post_data['author'] = stripslashes($user['username']);
     $comment_post_data['key'] = get_comment_post_key($params['image_id']);
   }
 
@@ -782,7 +781,7 @@ SELECT DISTINCT id FROM '.IMAGES_TABLE.'
     '    AND'
     ).'
     LIMIT 1';
-  if ( mysql_num_rows( pwg_query($query) )==0 )
+  if ( pwg_db_num_rows( pwg_query($query) )==0 )
   {
     return new PwgError(404, "Invalid image_id or access denied" );
   }
@@ -838,7 +837,7 @@ SELECT * FROM '.IMAGES_TABLE.'
 
     $image_ids = array_flip($image_ids);
     $result = pwg_query($query);
-    while ($row = mysql_fetch_assoc($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
       $image = array();
       foreach ( array('id', 'width', 'height', 'hit') as $k )
@@ -900,7 +899,7 @@ UPDATE '.IMAGES_TABLE.'
   SET level='.(int)$params['level'].'
   WHERE id IN ('.implode(',',$params['image_id']).')';
   $result = pwg_query($query);
-  $affected_rows = mysql_affected_rows();
+  $affected_rows = pwg_db_changes($result);
   if ($affected_rows)
   {
     include_once(PHPWG_ROOT_PATH.'admin/include/functions.php');
@@ -1144,7 +1143,7 @@ SELECT
   FROM '.IMAGES_TABLE.'
   WHERE id = '.$params['image_id'].'
 ;';
-  list($file_path, $original_sum) = mysql_fetch_row(pwg_query($query));
+  list($file_path, $original_sum) = pwg_db_fetch_row(pwg_query($query));
 
   // TODO only files added with web API can be updated with web API
 
@@ -1223,13 +1222,13 @@ SELECT
   FROM '.IMAGES_TABLE.'
   WHERE '.$where_clause.'
 ;';
-  list($counter) = mysql_fetch_row(pwg_query($query));
+  list($counter) = pwg_db_fetch_row(pwg_query($query));
   if ($counter != 0) {
     return new PwgError(500, 'file already exists');
   }
 
   // current date
-  list($dbnow) = mysql_fetch_row(pwg_query('SELECT NOW();'));
+  list($dbnow) = pwg_db_fetch_row(pwg_query('SELECT NOW();'));
   list($year, $month, $day) = preg_split('/[^\d]/', $dbnow, 4);
 
   // upload directory hierarchy
@@ -1297,7 +1296,7 @@ SELECT
     array($insert)
     );
 
-  $image_id = mysql_insert_id();
+  $image_id = pwg_db_insert_id(IMAGES_TABLE);
 
   // let's add links between the image and the categories
   if (isset($params['categories']))
@@ -1356,8 +1355,8 @@ function ws_session_getStatus($params, &$service)
 {
   global $user;
   $res = array();
-  $res['username'] = is_a_guest() ? 'guest' : $user['username'];
-  foreach ( array('status', 'template', 'theme', 'language') as $k )
+  $res['username'] = is_a_guest() ? 'guest' : stripslashes($user['username']);
+  foreach ( array('status', 'theme', 'language') as $k )
   {
     $res[$k] = $user[$k];
   }
@@ -1460,7 +1459,7 @@ SELECT image_id, GROUP_CONCAT(tag_id) tag_ids
   WHERE tag_id IN ('.implode(',',$tag_ids).')
   GROUP BY image_id';
       $result = pwg_query($query);
-      while ( $row=mysql_fetch_assoc($result) )
+      while ( $row=pwg_db_fetch_assoc($result) )
       {
         $row['image_id'] = (int)$row['image_id'];
         array_push( $image_ids, $row['image_id'] );
@@ -1500,10 +1499,10 @@ SELECT DISTINCT i.* FROM '.IMAGES_TABLE.' i
   WHERE '. implode('
     AND ', $where_clauses).'
 '.$order_by.'
-LIMIT '.(int)($params['per_page']*$params['page']).','.(int)$params['per_page'];
+LIMIT '.(int)$params['per_page'].' OFFSET '.(int)($params['per_page']*$params['page']);
 
     $result = pwg_query($query);
-    while ($row = mysql_fetch_assoc($result))
+    while ($row = pwg_db_fetch_assoc($result))
     {
       $image = array();
       foreach ( array('id', 'width', 'height', 'hit') as $k )
@@ -1713,10 +1712,10 @@ SELECT
   WHERE id = '.$params['image_id'].'
 ;';
   $result = pwg_query($query);
-  if (mysql_num_rows($result) == 0) {
+  if (pwg_db_num_rows($result) == 0) {
     return new PwgError(404, "image_id not found");
   }
-  list($path) = mysql_fetch_row($result);
+  list($path) = pwg_db_fetch_row($result);
 
   $ret = array();
 
@@ -1795,7 +1794,7 @@ SELECT *
   WHERE id = '.$params['image_id'].'
 ;';
 
-  $image_row = mysql_fetch_assoc(pwg_query($query));
+  $image_row = pwg_db_fetch_assoc(pwg_query($query));
   if ($image_row == null)
   {
     return new PwgError(404, "image_id not found");
@@ -2126,4 +2125,59 @@ function ws_logfile($string)
     FILE_APPEND
     );
 }
+
+function ws_images_checkUpload($params, &$service)
+{
+  global $conf;
+
+  if (!is_admin() or is_adviser())
+  {
+    return new PwgError(401, 'Access denied');
+  }
+
+  $ret['message'] = ready_for_upload_message();
+  $ret['ready_for_upload'] = true;
+  
+  if (!empty($ret['message']))
+  {
+    $ret['ready_for_upload'] = false;
+  }
+  
+  return $ret;
+}
+
+function ready_for_upload_message()
+{
+  global $conf;
+
+  $relative_dir = preg_replace('#^'.PHPWG_ROOT_PATH.'#', '', $conf['upload_dir']);
+
+  if (!is_dir($conf['upload_dir']))
+  {
+    if (!is_writable(dirname($conf['upload_dir'])))
+    {
+      return sprintf(
+        l10n('Create the "%s" directory at the root of your Piwigo installation'),
+        $relative_dir
+        );
+    }
+  }
+  else
+  {
+    if (!is_writable($conf['upload_dir']))
+    {
+      @chmod($conf['upload_dir'], 0777);
+      
+      if (!is_writable($conf['upload_dir']))
+      {
+        return sprintf(
+          l10n('Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'),
+          $relative_dir
+          );
+      }
+    }
+  }
+
+  return null;
+}
 ?>
