@@ -2,7 +2,7 @@
 // +-----------------------------------------------------------------------+
 // | Piwigo - a PHP based picture gallery                                  |
 // +-----------------------------------------------------------------------+
-// | Copyright(C) 2008-2009 Piwigo Team                  http://piwigo.org |
+// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
 // | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
 // | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
 // +-----------------------------------------------------------------------+
@@ -56,7 +56,7 @@ SELECT id, file, level
       str_replace(array('_','%'), array('/_','/%'), $page['image_file'] ).
       '.%" ESCAPE "/" LIMIT 1';
   }
-  if ( ! ( $row = mysql_fetch_array(pwg_query($query)) ) )
+  if ( ! ( $row = pwg_db_fetch_assoc(pwg_query($query)) ) )
   {// element does not exist
     page_not_found( 'The requested image does not exist',
       duplicate_index_url()
@@ -66,7 +66,9 @@ SELECT id, file, level
   {
     access_denied();
   }
-  list($page['image_id'], $page['image_file']) =  $row;
+
+  $page['image_id'] = $row['id'];
+  $page['image_file'] =  $row['file'];
   if ( !isset($page['rank_of'][$page['image_id']]) )
   {// the image can still be non accessible (filter/cat perm) and/or not in the set
     global $filter;
@@ -92,7 +94,7 @@ SELECT id
             " AND"
           ).'
   LIMIT 1';
-      if ( mysql_num_rows( pwg_query($query) ) == 0 )
+      if ( pwg_db_num_rows( pwg_query($query) ) == 0 )
       {
         access_denied();
       }
@@ -307,23 +309,73 @@ UPDATE '.CATEGORIES_TABLE.'
         );
       redirect($url_self);
     }
+    case 'edit_comment' :
+    {
+      check_pwg_token();
+
+      include_once(PHPWG_ROOT_PATH.'include/functions_comment.inc.php');
+
+      check_input_parameter('comment_to_edit', $_GET, false, PATTERN_ID);
+
+      $author_id = get_comment_author_id($_GET['comment_to_edit']);
+
+      if (can_manage_comment('edit', $author_id))
+      {
+        if (!empty($_POST['content']))
+        {
+          update_user_comment(
+            array(
+              'comment_id' => $_GET['comment_to_edit'],
+              'image_id' => $page['image_id'],
+              'content' => $_POST['content']
+              ),
+            $_POST['key']
+            );
+
+          redirect($url_self);
+        }
+        else
+        {
+          $edit_comment = $_GET['comment_to_edit'];
+          break;
+        }
+      }
+    }
     case 'delete_comment' :
     {
       check_pwg_token();
-      
-      if (isset($_GET['comment_to_delete'])
-          and is_numeric($_GET['comment_to_delete'])
-          and is_admin() and !is_adviser() )
+
+      include_once(PHPWG_ROOT_PATH.'include/functions_comment.inc.php');
+
+      check_input_parameter('comment_to_delete', $_GET, false, PATTERN_ID);
+
+      $author_id = get_comment_author_id($_GET['comment_to_delete']);
+
+      if (can_manage_comment('delete', $author_id))
       {
-        $query = '
-DELETE FROM '.COMMENTS_TABLE.'
-  WHERE id = '.$_GET['comment_to_delete'].'
-;';
-        pwg_query( $query );
+        delete_user_comment($_GET['comment_to_delete']);
       }
 
       redirect($url_self);
     }
+    case 'validate_comment' :
+    {
+      check_pwg_token();
+
+      include_once(PHPWG_ROOT_PATH.'include/functions_comment.inc.php');
+
+      check_input_parameter('comment_to_validate', $_GET, false, PATTERN_ID);
+
+      $author_id = get_comment_author_id($_GET['comment_to_validate']);
+
+      if (can_manage_comment('validate', $author_id))
+      {
+        validate_user_comment($_GET['comment_to_validate']);
+      }
+
+      redirect($url_self);
+    }
+
   }
 }
 
@@ -356,8 +408,9 @@ SELECT category_id,uppercats,commentable,global_rank
 ;';
 $result = pwg_query($query);
 $related_categories = array();
-while ($row = mysql_fetch_array($result))
+while ($row = pwg_db_fetch_assoc($result))
 {
+  $row['commentable'] = boolean_to_string($row['commentable']);
   array_push($related_categories, $row);
 }
 usort($related_categories, 'global_rank_compare');
@@ -384,7 +437,7 @@ SELECT *
 
 $result = pwg_query($query);
 
-while ($row = mysql_fetch_assoc($result))
+while ($row = pwg_db_fetch_assoc($result))
 {
   if (isset($page['previous_item']) and $row['id'] == $page['previous_item'])
   {
@@ -502,12 +555,6 @@ if (!empty($picture['current']['width']))
     );
 }
 
-$url_admin =
-  get_root_url().'admin.php?page=picture_modify'
-  .'&amp;cat_id='.(isset($page['category']) ? $page['category']['id'] : '')
-  .'&amp;image_id='.$page['image_id']
-;
-
 $slideshow_params = array();
 $slideshow_url_params = array();
 
@@ -583,7 +630,6 @@ if ( $metadata_showable and pwg_get_session_var('show_metadata') )
 }
 
 
-
 $page['body_id'] = 'thePicturePage';
 
 // allow plugins to change what we computed before passing data to template
@@ -612,10 +658,13 @@ foreach (array('first','previous','next','last', 'current') as $which_image)
           'U_IMG' =>
             add_url_params(
               $picture[$which_image]['url'], $slideshow_url_params),
-          'U_DOWNLOAD' => @$picture['current']['download_url'],
           )
         )
       );
+    if ($conf['picture_download_icon'] and !empty($picture['current']['download_url']))
+    {
+      $template->append($which_image, array('U_DOWNLOAD' => $picture['current']['download_url']), true);
+    }
   }
 }
 
@@ -671,7 +720,7 @@ if ($page['slideshow'])
   }
   $template->assign('slideshow', $tpl_slideshow );
 }
-else
+elseif ($conf['picture_slideshow_icon'])
 {
   $template->assign(
     array(
@@ -693,10 +742,16 @@ $template->assign(
     'LEVEL_SEPARATOR' => $conf['level_separator'],
 
     'U_UP' => $url_up,
-    'U_METADATA' => $url_metadata,
+    'DISPLAY_NAV_BUTTONS' => $conf['picture_navigation_icons'],
+    'DISPLAY_NAV_THUMB' => $conf['picture_navigation_thumb']
     )
   );
 
+if ($conf['picture_metadata_icon'])
+{
+  $template->assign('U_METADATA', $url_metadata);
+}
+
 
 //------------------------------------------------------- upper menu management
 
@@ -714,6 +769,11 @@ if (is_admin())
       );
   }
 
+  $url_admin =
+    get_root_url().'admin.php?page=picture_modify'
+    .'&amp;cat_id='.(isset($page['category']) ? $page['category']['id'] : '')
+    .'&amp;image_id='.$page['image_id'];
+
   $template->assign(
     array(
       'U_CADDIE' => add_url_params($url_self,
@@ -722,10 +782,12 @@ if (is_admin())
       'U_ADMIN' => $url_admin,
       )
     );
+
+  $template->assign('available_permission_levels', get_privacy_level_options());
 }
 
 // favorite manipulation
-if (!is_a_guest())
+if (!is_a_guest() and $conf['picture_favorite_icon'])
 {
   // verify if the picture is already in the favorite of the user
   $query = '
@@ -734,39 +796,22 @@ SELECT COUNT(*) AS nb_fav
   WHERE image_id = '.$page['image_id'].'
     AND user_id = '.$user['id'].'
 ;';
-  $result = pwg_query($query);
-  $row = mysql_fetch_array($result);
+  $row = pwg_db_fetch_assoc( pwg_query($query) );
+	$is_favorite = $row['nb_fav'] != 0;
 
-  if ($row['nb_fav'] == 0)
-  {
-    $template->assign(
-      'favorite',
-      array(
-        'FAVORITE_IMG'  =>
-          get_root_url().get_themeconf('icon_dir').'/favorite.png',
-        'FAVORITE_HINT' => l10n('add_favorites_hint'),
-        'U_FAVORITE'    => add_url_params(
-          $url_self,
-          array('action'=>'add_to_favorites')
-          ),
-        )
-      );
-  }
-  else
-  {
-    $template->assign(
-      'favorite',
-      array(
-        'FAVORITE_IMG'  =>
-          get_root_url().get_themeconf('icon_dir').'/del_favorite.png',
-        'FAVORITE_HINT' => l10n('del_favorites_hint'),
-        'U_FAVORITE'    => add_url_params(
-          $url_self,
-          array('action'=>'remove_from_favorites')
-          ),
-        )
-      );
-  }
+  $template->assign(
+    'favorite',
+    array(
+			'IS_FAVORITE' => $is_favorite,
+      'FAVORITE_IMG'  =>
+        get_root_url().get_themeconf('icon_dir').(!$is_favorite ? '/favorite.png' : '/del_favorite.png' ),
+      'FAVORITE_HINT' => l10n( !$is_favorite ? 'add this image to your favorites' : 'delete this image from your favorites'),
+      'U_FAVORITE'    => add_url_params(
+        $url_self,
+        array('action'=> !$is_favorite ? 'add_to_favorites' : 'remove_from_favorites' )
+        ),
+      )
+    );
 }
 
 //--------------------------------------------------------- picture information
@@ -859,6 +904,7 @@ $infos['INFO_VISITS'] = $picture['current']['hit'];
 $infos['INFO_FILE'] = $picture['current']['file'];
 
 $template->assign($infos);
+$template->assign('display_info', unserialize($conf['picture_informations']));
 
 // related tags
 $tags = get_common_tags( array($page['image_id']), -1);
@@ -930,10 +976,6 @@ $element_content = trigger_event(
   );
 $template->assign( 'ELEMENT_CONTENT', $element_content );
 
-if (is_admin())
-{
-  $template->assign('available_permission_levels', $conf['available_permission_levels']);
-}
 // +-----------------------------------------------------------------------+
 // |                               sub pages                               |
 // +-----------------------------------------------------------------------+
@@ -958,4 +1000,4 @@ else
 //------------------------------------------------------------ log informations
 pwg_log($picture['current']['id'], 'picture');
 include(PHPWG_ROOT_PATH.'include/page_tail.php');
-?>
+?>
\ No newline at end of file
